@@ -190,15 +190,11 @@ OC.L10N.register(
     "At event start" : "في بداية الحدث",
     "No reminder" : "لا يوجد تذكير ",
     "Failed to save default calendar" : "تعذّر حفظ التقويم التلقائي",
-    "CalDAV link copied to clipboard." : "تم نسخ CalDAV.",
-    "CalDAV link could not be copied to clipboard." : "لا يمكن نسخ CalDAV.",
     "General" : "عامٌّ",
-    "Copy iOS/macOS CalDAV address" : "نسخ عنوان CalDAV لأجهزة الماك/الأيفون",
     "Appearance" : "المظهر",
     "Editing" : "جارِ التعديل",
-    "Default calendar for incoming invitations" : "التقويم التلقائي للدعوات الواردة",
     "Default reminder" : "التذكير الافتراضي",
-    "Keyboard shortcuts" : "اختصارات لوحة المفاتيح",
+    "Files" : "الملفّات",
     "Appointment schedule successfully created" : "تمّ إنشاء جدول المواعيد بنجاح",
     "Appointment schedule successfully updated" : "تمّ تحديث جدول المواعيد بنجاح",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} دقائق","{duration} دقيقة","{duration} دقائق","{duration} دقائق","{duration} دقائق","{duration} دقائق"],
@@ -258,6 +254,7 @@ OC.L10N.register(
     "Successfully added Talk conversation link to location." : "تمت إضافة رابط المحادثة إلى الموقع بنجاح.",
     "Successfully added Talk conversation link to description." : "تمت إضافة رابط المحادثة إلى الوصف بنجاح.",
     "Failed to apply Talk room." : "تعذّر تطبيق غرفة المحادثة.",
+    "Talk conversation for event" : "محادثة الحدث ",
     "Error creating Talk conversation" : "خطأ في إنشاء رابط المحادثة",
     "Select a Talk Room" : "إختَر غرفة المحادثة",
     "Add Talk conversation" : "إضِف محادثة Talk",
@@ -340,12 +337,7 @@ OC.L10N.register(
     "Decline" : "رفض",
     "Tentative" : "مؤقت",
     "No attendees yet" : "لا يوجد حضور حتى الآن",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} مدعو, {confirmedCount} مؤكد",
-    "Successfully appended link to talk room to location." : "تمّ إلحاق رابط غرفة المحادثة بالموقع بنجاح.",
-    "Successfully appended link to talk room to description." : "تمّ إلحاق الرابط بوصف غرفة المحادثة بنجاح.",
-    "Error creating Talk room" : "خطأ في انشاء غرفة محادثة",
     "Attendees" : "المشاركون",
-    "_%n more guest_::_%n more guests_" : ["%n ضيفاً آخر","%n ضيفاً آخر","%n ضيفاً آخر","%n ضيوف آخرين","%n ضيفاً آخر","%n ضيفاً آخر"],
     "Remove group" : "حذف مجموعة",
     "Remove attendee" : "إلغاء شخص من قائمة الحضور",
     "Request reply" : "طلب الرّد",
@@ -574,7 +566,6 @@ OC.L10N.register(
     "Error while sharing file with user" : "حدث خطأ أثناء مُشاركة الملف مع مُستخدِم",
     "Attachment {fileName} already exists!" : "المُرفَق {fileName} موجودٌ سلفاً!",
     "An error occurred during getting file information" : "حدث خطأ أثناء جلب بيانات الملف",
-    "Talk conversation for event" : "محادثة الحدث ",
     "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
     "Imported {filename}" : "إستيراد {filename}",
     "This is an event reminder." : "هذا تذكير بحدث",
@@ -587,6 +578,8 @@ OC.L10N.register(
     "Default attachments location" : "موقع المُرفقات التلقائي",
     "Automatic ({detected})" : "تلقائي ({detected})",
     "Shortcut overview" : "نظرة عامة للاختصارات",
+    "CalDAV link copied to clipboard." : "تم نسخ CalDAV.",
+    "CalDAV link could not be copied to clipboard." : "لا يمكن نسخ CalDAV.",
     "Enable birthday calendar" : "تفعيل تقويم عيد الميلاد",
     "Show tasks in calendar" : "إظهار المهام في التقويم",
     "Enable simplified editor" : "تفعيل المحرر البسيط",
@@ -594,9 +587,17 @@ OC.L10N.register(
     "Show weekends" : "إظهار أيام نهاية الاسبوع",
     "Show week numbers" : "إظهار أرقام الأسابيع",
     "Time increments" : "زيادات الوقت",
+    "Default calendar for incoming invitations" : "التقويم التلقائي للدعوات الواردة",
     "Copy primary CalDAV address" : "نسخ عنوان CalDAV الرئيسي",
+    "Copy iOS/macOS CalDAV address" : "نسخ عنوان CalDAV لأجهزة الماك/الأيفون",
     "Personal availability settings" : "إعدادات التواجد الشخصي",
     "Show keyboard shortcuts" : "إظهار اختصارات لوحة المفاتيح",
-    "The visibility of this event in shared calendars." : "ظهور الحدث في التقاويم المشتركة."
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} مدعو, {confirmedCount} مؤكد",
+    "Successfully appended link to talk room to location." : "تمّ إلحاق رابط غرفة المحادثة بالموقع بنجاح.",
+    "Successfully appended link to talk room to description." : "تمّ إلحاق الرابط بوصف غرفة المحادثة بنجاح.",
+    "Error creating Talk room" : "خطأ في انشاء غرفة محادثة",
+    "_%n more guest_::_%n more guests_" : ["%n ضيفاً آخر","%n ضيفاً آخر","%n ضيفاً آخر","%n ضيوف آخرين","%n ضيفاً آخر","%n ضيفاً آخر"],
+    "The visibility of this event in shared calendars." : "ظهور الحدث في التقاويم المشتركة.",
+    "Keyboard shortcuts" : "اختصارات لوحة المفاتيح"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
