@@ -110,7 +110,6 @@ OC.L10N.register(
     "Share with users or groups" : "Compartir con usuarios o grupos",
     "No users or groups" : "Nun hai nengún usuariu nin grupu",
     "Failed to save calendar name and color" : "Nun se pue guardar el nome y el color del calendariu",
-    "Calendar name …" : "Nome del calendariu…",
     "Share calendar" : "Compartir el calendariu",
     "Save" : "Guardar",
     "View" : "Ver",
@@ -141,18 +140,10 @@ OC.L10N.register(
     "Calendar settings" : "Configuración del calendariu",
     "No reminder" : "Nun hai nengún recordatoriu",
     "Failed to save default calendar" : "Nun se pue guardar el calendariu predetermináu",
-    "CalDAV link copied to clipboard." : "L'enllaz CalDAV copióse nel cartafueyu.",
-    "CalDAV link could not be copied to clipboard." : "L'enllaz CalDAV nun se pudo copiar nel cartafueyu.",
     "General" : "Xeneral",
-    "Personal availability settings" : "Configuración de la disponibilidá personal",
-    "Copy primary CalDAV address" : "Copiar la direición CalDAV primaria",
-    "Copy iOS/macOS CalDAV address" : "Copiar la direición CalDAV d'iOS/macOS",
-    "Enable birthday calendar" : "Activar el calendariu de los cumpleaños",
-    "Show tasks in calendar" : "Amosar les xeres nel calendariu",
-    "Show weekends" : "Amosar les fines de selmana",
-    "Show week numbers" : "Amosar los númberos de selmana",
+    "Appearance" : "Aspeutu",
     "Default reminder" : "Recordatoriu predetermináu",
-    "Keyboard shortcuts" : "Atayos del tecláu",
+    "Files" : "Ficheros",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minutu","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} hores"],
@@ -218,9 +209,7 @@ OC.L10N.register(
     "Decline" : "Refugar",
     "Tentative" : "Provisional",
     "No attendees yet" : "Nun hai nengún asistente",
-    "Error creating Talk room" : "Hebo un error al crear la sala de Talk",
     "Attendees" : "Asistentes",
-    "_%n more guest_::_%n more guests_" : ["%n convidáu más","%n convidaos más"],
     "Remove group" : "Quitar el grupu",
     "_%n member_::_%n members_" : ["%n miembru","%n miembros"],
     "No match found" : "Nun s'atopó nenguna coincidencia",
@@ -244,6 +233,7 @@ OC.L10N.register(
     "More details" : "Mas detalles",
     "Yes" : "Sí",
     "No" : "Non",
+    "None" : "Nada",
     "Create" : "Crear",
     "Please enter a valid date" : "Introduz una data válida",
     "Pick a date" : "Escueyi una data",
@@ -295,8 +285,21 @@ OC.L10N.register(
     "This is an event reminder." : "Esto ye un recordatoriu del eventu.",
     "User not found" : "Nun s'atopó l'usuariu",
     "Hidden" : "Anubrióse",
+    "Calendar name …" : "Nome del calendariu…",
+    "CalDAV link copied to clipboard." : "L'enllaz CalDAV copióse nel cartafueyu.",
+    "CalDAV link could not be copied to clipboard." : "L'enllaz CalDAV nun se pudo copiar nel cartafueyu.",
+    "Enable birthday calendar" : "Activar el calendariu de los cumpleaños",
+    "Show tasks in calendar" : "Amosar les xeres nel calendariu",
     "Enable simplified editor" : "Activar l'editor simplificáu",
     "Limit the number of events displayed in the monthly view" : "Llendar el númberu d'eventos amosaos na vista de meses",
-    "Show keyboard shortcuts" : "Amosar los atayos del tecáu"
+    "Show weekends" : "Amosar les fines de selmana",
+    "Show week numbers" : "Amosar los númberos de selmana",
+    "Copy primary CalDAV address" : "Copiar la direición CalDAV primaria",
+    "Copy iOS/macOS CalDAV address" : "Copiar la direición CalDAV d'iOS/macOS",
+    "Personal availability settings" : "Configuración de la disponibilidá personal",
+    "Show keyboard shortcuts" : "Amosar los atayos del tecáu",
+    "Error creating Talk room" : "Hebo un error al crear la sala de Talk",
+    "_%n more guest_::_%n more guests_" : ["%n convidáu más","%n convidaos más"],
+    "Keyboard shortcuts" : "Atayos del tecláu"
 },
 "nplurals=2; plural=(n != 1);");
