@@ -188,15 +188,11 @@ OC.L10N.register(
     "At event start" : "A l'inici de l'esdeveniment",
     "No reminder" : "Sense recordatoris",
     "Failed to save default calendar" : "No s'ha pogut desar el calendari predeterminat",
-    "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
-    "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
     "General" : "General",
-    "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
     "Appearance" : "Aparença",
     "Editing" : "Edició",
-    "Default calendar for incoming invitations" : "Calendari predeterminat per a les invitacions entrants",
     "Default reminder" : "Recordatori per defecte",
-    "Keyboard shortcuts" : "Dreceres de teclat",
+    "Files" : "Fitxers",
     "Appointment schedule successfully created" : "S'ha creat correctament la planificació de cites",
     "Appointment schedule successfully updated" : "La planificació de cites s'ha actualitzat correctament",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuts"],
@@ -256,9 +252,10 @@ OC.L10N.register(
     "Successfully added Talk conversation link to location." : "S'ha afegit correctament l'enllaç de Converses a la ubicació.",
     "Successfully added Talk conversation link to description." : "S'ha afegit correctament l'enllaç de Converses a la descripció.",
     "Failed to apply Talk room." : "No s'ha pogut aplicar la sala de Converses.",
+    "Talk conversation for event" : "Converses per a l'esdeveniment",
     "Error creating Talk conversation" : "S'ha produït un error en crear la Converses",
     "Select a Talk Room" : "Seleccioneu una sala de Converses",
-    "Add Talk conversation" : "Afegeix una Converses",
+    "Add Talk conversation" : "Afegeix a Converses",
     "Fetching Talk rooms…" : "S'estan obtenint sales de Converses…",
     "No Talk room available" : "No hi ha sala de Converses disponible",
     "Select conversation" : "Seleccioneu una conversa",
@@ -338,9 +335,6 @@ OC.L10N.register(
     "Decline" : "Rebutja",
     "Tentative" : "Provisional",
     "No attendees yet" : "Encara no hi ha cap participant",
-    "Successfully appended link to talk room to location." : "S'ha afegit correctament l'enllaç a la sala de conversa a la ubicació.",
-    "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala de Talk a la descripció de l'esdeveniment.",
-    "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
     "Attendees" : "Assistents",
     "Remove group" : "Suprimir el grup",
     "Remove attendee" : "Suprimeix el participant",
@@ -571,7 +565,6 @@ OC.L10N.register(
     "Error while sharing file with user" : "S'ha produït un error en compartir el fitxer amb l'usuari",
     "Attachment {fileName} already exists!" : "El fitxer adjunt {fileName} ja existeix!",
     "An error occurred during getting file information" : "S'ha produït un error en obtenir la informació del fitxer",
-    "Talk conversation for event" : "Converses per a l'esdeveniment",
     "An error occurred, unable to delete the calendar." : "S'ha produït un error. No s'ha suprimit el calendari.",
     "Imported {filename}" : "{filename} importat",
     "This is an event reminder." : "Això és un recordatori de l'esdeveniment.",
@@ -584,6 +577,8 @@ OC.L10N.register(
     "Default attachments location" : "Ubicació per defecte dels fitxers adjunts",
     "Automatic ({detected})" : "Automàtic ({detected})",
     "Shortcut overview" : "Descripció general de la drecera",
+    "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
+    "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
     "Enable birthday calendar" : "Habilitar el calendari d'aniversaris",
     "Show tasks in calendar" : "Mostra les tasques en el calendari",
     "Enable simplified editor" : "Habilitar l'editor simplificat",
@@ -591,11 +586,17 @@ OC.L10N.register(
     "Show weekends" : "Mostra els caps de setmana",
     "Show week numbers" : "Mostra el número de la setmana",
     "Time increments" : "Increments de temps",
+    "Default calendar for incoming invitations" : "Calendari predeterminat per a les invitacions entrants",
     "Copy primary CalDAV address" : "Copia l'adreça CalDAV primària",
+    "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
     "Personal availability settings" : "Paràmetres de disponibilitat personal",
     "Show keyboard shortcuts" : "Mostra les dreceres del teclat",
     "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} convidats, {confirmedCount} confirmats",
+    "Successfully appended link to talk room to location." : "S'ha afegit correctament l'enllaç a la sala de conversa a la ubicació.",
+    "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala de Talk a la descripció de l'esdeveniment.",
+    "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
     "_%n more guest_::_%n more guests_" : ["%n convidat més","%n convidats més"],
-    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits."
+    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits.",
+    "Keyboard shortcuts" : "Dreceres de teclat"
 },
 "nplurals=2; plural=(n != 1);");
