@@ -38,12 +38,10 @@ OC.L10N.register(
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
     "Deck" : "Deck",
-    "Hidden" : "Oculto",
     "Copy internal link" : "Copiar enlace interno",
     "Share link" : "Compartir link",
     "Copy public link" : "Copiar link publico",
     "Copied code" : "Código copiado",
-    "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con usuarios o grupos",
     "No users or groups" : "No hay usuarios ni grupos.",
     "Save" : "Guardar",
@@ -51,13 +49,13 @@ OC.L10N.register(
     "Filename" : "Nombre de archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
+    "Automatic ({timezone})" : "Automático ({timezone})",
     "Timezone" : "Zona horaria",
     "List view" : "Vista de lista",
     "Actions" : "Acciones",
     "General" : "General",
-    "Show week numbers" : "Mostrar número de semana",
     "Editing" : "Editando",
-    "Keyboard shortcuts" : "Atajos de teclado",
+    "Files" : "Archivo",
     "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
@@ -99,6 +97,7 @@ OC.L10N.register(
     "Resources" : "Recursos",
     "available" : "disponible",
     "Yes" : "Sí",
+    "None" : "Ninguno",
     "Global" : "Global",
     "Subscribe" : "Suscribirse",
     "Select a date" : "Elija una fecha",
@@ -121,6 +120,10 @@ OC.L10N.register(
     "When shared hide this event" : "Al compartir, ocultar este evento ",
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
-    "Categories" : "Categoría"
+    "Categories" : "Categoría",
+    "Hidden" : "Oculto",
+    "can edit" : "puede editar",
+    "Show week numbers" : "Mostrar número de semana",
+    "Keyboard shortcuts" : "Atajos de teclado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
