@@ -179,14 +179,11 @@ OC.L10N.register(
     "or" : "o",
     "Calendar settings" : "Configuración del calendario",
     "No reminder" : "Sin recordatorio",
-    "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
-    "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
     "General" : "General",
-    "Copy iOS/macOS CalDAV address" : "Copiar dirección CalDAV para iOS/macOS",
     "Appearance" : "Apariencia",
     "Editing" : "Edición",
     "Default reminder" : "Recordatorio predeterminado",
-    "Keyboard shortcuts" : "Atajos del teclado",
+    "Files" : "Archivo",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
@@ -290,8 +287,6 @@ OC.L10N.register(
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
     "No attendees yet" : "Aún no hay asistentes",
-    "Successfully appended link to talk room to description." : "Enlace a la sala de Talk se agregó correctamente a la descripción.",
-    "Error creating Talk room" : "Error al crear la sala de Talk",
     "Attendees" : "Asistentes",
     "Remove group" : "Eliminar grupo",
     "Remove attendee" : "Eliminar asistente",
@@ -499,6 +494,8 @@ OC.L10N.register(
     "Default attachments location" : "Ubicación predeterminada para adjuntos",
     "Automatic ({detected})" : "Automático ({detected})",
     "Shortcut overview" : "Resumen de accesos directos",
+    "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
+    "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
     "Enable birthday calendar" : "Habilitar calendario de cumpleaños",
     "Show tasks in calendar" : "Mostrar tareas en el calendario",
     "Enable simplified editor" : "Habilitar editor simplificado",
@@ -507,8 +504,12 @@ OC.L10N.register(
     "Show week numbers" : "Mostrar número de semana",
     "Time increments" : "Incrementos de tiempo",
     "Copy primary CalDAV address" : "Copiar dirección CalDAV principal",
+    "Copy iOS/macOS CalDAV address" : "Copiar dirección CalDAV para iOS/macOS",
     "Personal availability settings" : "Configuración de disponibilidad personal",
     "Show keyboard shortcuts" : "Mostrar accesos directos de teclado",
-    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
+    "Successfully appended link to talk room to description." : "Enlace a la sala de Talk se agregó correctamente a la descripción.",
+    "Error creating Talk room" : "Error al crear la sala de Talk",
+    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos.",
+    "Keyboard shortcuts" : "Atajos del teclado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
