@@ -28,7 +28,6 @@ OC.L10N.register(
     "Delete permanently" : "Borrar permanentemente",
     "Deck" : "Deck",
     "Share link" : "Compartir liga",
-    "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "Save" : "Guardar",
     "Filename" : "Nombre del archivo",
@@ -40,8 +39,7 @@ OC.L10N.register(
     "Actions" : "Acciones",
     "or" : "o",
     "General" : "General",
-    "Show week numbers" : "Mostrar número de semana",
-    "Keyboard shortcuts" : "Atajos del teclado",
+    "Files" : "Archivo",
     "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
@@ -92,6 +90,9 @@ OC.L10N.register(
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
     "User not found" : "No se encontró el usuario",
-    "Hidden" : "Oculto"
+    "Hidden" : "Oculto",
+    "can edit" : "puede editar",
+    "Show week numbers" : "Mostrar número de semana",
+    "Keyboard shortcuts" : "Atajos del teclado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
