@@ -130,7 +130,6 @@ OC.L10N.register(
     "Deleting share link …" : "در حال حذف پیوند اشتراک ...",
     "An error occurred while unsharing the calendar." : "An error occurred while unsharing the calendar.",
     "An error occurred, unable to change the permission of the share." : "خطایی روی داد ، قادر به تغییر مجوز اشتراک نیست.",
-    "can edit" : "می توان ویرایش کرد",
     "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
     "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
     "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
@@ -150,7 +149,7 @@ OC.L10N.register(
     "Invalid location selected" : "مکان نامعتبر انتخاب شده است",
     "Attachments folder successfully saved." : "Attachments folder successfully saved.",
     "Error on saving attachments folder." : "Error on saving attachments folder.",
-    "Default attachments location" : "Default attachments location",
+    "Attachments folder" : "Attachments folder",
     "{filename} could not be parsed" : "{filename} could not be parsed",
     "No valid files found, aborting import" : "No valid files found, aborting import",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Successfully imported %n event","Successfully imported %n events"],
@@ -178,19 +177,11 @@ OC.L10N.register(
     "or" : "یا",
     "Calendar settings" : "تنظیمات تقویم",
     "No reminder" : "No reminder",
-    "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
-    "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
     "General" : "عمومی",
-    "Personal availability settings" : "Personal availability settings",
-    "Copy primary CalDAV address" : "آدرس اصلی CalDAV را کپی کنید",
-    "Copy iOS/macOS CalDAV address" : "آدرس CalDAV iOS / macOS را کپی کنید",
-    "Enable birthday calendar" : "تقویم تولد را فعال کنید",
-    "Show tasks in calendar" : "نمایش وظایف در تقویم",
-    "Show weekends" : "آخر هفته ها را نشان دهید",
-    "Show week numbers" : "نمایش شماره های هفته",
+    "Appearance" : "ظاهر",
     "Editing" : "ویرایش کردن",
     "Default reminder" : "Default reminder",
-    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
+    "Files" : "پرونده‌ها",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes"],
     "0 minutes" : "0 minutes",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} hours"],
@@ -297,9 +288,6 @@ OC.L10N.register(
     "Decline" : "کاهش می یابد",
     "Tentative" : "آزمایشی",
     "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
-    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
-    "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
-    "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
     "Attendees" : "شرکت کنندگان",
     "Remove group" : "برداشتن گروه",
     "Remove attendee" : "شرکت کننده را حذف کنید",
@@ -482,7 +470,6 @@ OC.L10N.register(
     "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
     "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
     "When shared hide this event" : "هنگام اشتراک گذاری این رویداد را پنهان کنید",
-    "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک.",
     "Add a location" : "افزودن یک محل",
     "Status" : "وضعیت",
     "Confirmed" : "تایید شده",
@@ -506,12 +493,28 @@ OC.L10N.register(
     "Appointment not found" : "Appointment not found",
     "User not found" : "کاربر یافت نشد",
     "Hidden" : "مخفی",
+    "can edit" : "می توان ویرایش کرد",
     "Calendar name …" : "نام تقویم …",
+    "Default attachments location" : "Default attachments location",
     "Automatic ({detected})" : "خودکار ({شناسایی})",
     "Shortcut overview" : "Shortcut overview",
+    "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
+    "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
+    "Enable birthday calendar" : "تقویم تولد را فعال کنید",
+    "Show tasks in calendar" : "نمایش وظایف در تقویم",
     "Enable simplified editor" : "ویرایشگر ساده شده را فعال کنید",
     "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
+    "Show weekends" : "آخر هفته ها را نشان دهید",
+    "Show week numbers" : "نمایش شماره های هفته",
     "Time increments" : "Time increments",
-    "Show keyboard shortcuts" : "Show keyboard shortcuts"
+    "Copy primary CalDAV address" : "آدرس اصلی CalDAV را کپی کنید",
+    "Copy iOS/macOS CalDAV address" : "آدرس CalDAV iOS / macOS را کپی کنید",
+    "Personal availability settings" : "Personal availability settings",
+    "Show keyboard shortcuts" : "Show keyboard shortcuts",
+    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
+    "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
+    "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
+    "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک.",
+    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید"
 },
 "nplurals=2; plural=(n > 1);");
