@@ -142,7 +142,6 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (tiimi)",
     "An error occurred while unsharing the calendar." : "Kalenterin jaon poistamisessa tapahtui virhe.",
     "An error occurred, unable to change the permission of the share." : "Tapahtui virhe, jaon käyttöoikeuksia ei pysty muokkaamaan.",
-    "can edit" : "voi muokata",
     "Unshare with {displayName}" : "Poista jako kohteesta {displayName}",
     "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
     "No users or groups" : "Ei käyttäjiä tai ryhmiä",
@@ -170,7 +169,7 @@ OC.L10N.register(
     "Invalid location selected" : "Virheellinen sijainti valittu",
     "Attachments folder successfully saved." : "Liitteiden kansio tallennettu.",
     "Error on saving attachments folder." : "Virhe liitetiedostokansiota tallennettaessa.",
-    "Default attachments location" : "Liitteiden oletussijainti",
+    "Attachments folder" : "Liitteiden kansio",
     "{filename} could not be parsed" : "Tiedostoa {filename} ei voitu jäsentää",
     "No valid files found, aborting import" : "Kelvollisia tiedostoja ei löytynyt, lopetetaan tuonti",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Tuotiin onnistuneesti %n tapahtuma","Tuotiin onnistuneesti %n tapahtumaa"],
@@ -201,21 +200,10 @@ OC.L10N.register(
     "At event start" : "Tapahtuman alkaessa",
     "No reminder" : "Ei muistutusta",
     "Failed to save default calendar" : "Oletuskalenterin tallentaminen epäonnistui",
-    "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
     "General" : "Yleiset",
-    "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
-    "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
-    "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
-    "View options" : "Näkymävalinnat",
-    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
-    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
-    "Show weekends" : "Näytä viikonloput",
-    "Show week numbers" : "Näytä viikkonumerot",
-    "Limit number of events shown in month view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
-    "Default calendar for incoming invitations" : "Oletuskalenteri saapuville kutsuille",
+    "Appearance" : "Ulkoasu",
     "Default reminder" : "Oletusmuistutus",
-    "Keyboard shortcuts" : "Pikanäppäimet",
+    "Files" : "Tiedostot",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuutti","{duration} minuuttia"],
     "0 minutes" : "0 minuuttia",
     "_{duration} hour_::_{duration} hours_" : ["{duration} tunti","{duration} tuntia"],
@@ -271,12 +259,12 @@ OC.L10N.register(
     "Conversation does not have a valid URL." : "Keskustelulla ei ole kelvollista URL-osoitetta.",
     "Successfully added Talk conversation link to location." : "Talk-keskustelulinkki lisätty sijaintiin.",
     "Successfully added Talk conversation link to description." : "Talk-keskustelulinkki lisätty kuvaukseen.",
+    "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
     "Error creating Talk conversation" : "Virhe luotaessa Talk-keskustelua",
     "Select a Talk Room" : "Valitse Talk-huone",
     "Add Talk conversation" : "Lisää Talk-keskustelu",
     "Fetching Talk rooms…" : "Noudetaan Talk-huoneita…",
     "No Talk room available" : "Talk-huonetta ei ole käytettävissä",
-    "Create a new public conversation" : "Luo uusi julkinen keskustelu",
     "Select conversation" : "Valitse keskustelu",
     "on" : "päivä",
     "at" : "kellonaika",
@@ -300,7 +288,6 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
     "Attachment {name} already exist!" : "Liite {name} on jo olemassa!",
     "Could not upload attachment(s)" : "Liitteiden lähetys epäonnistui",
-    "You are about to download a file. Please check the file name before opening it. Are you sure to proceed?" : "Olet aikeissa ladata tiedoston. Tarkista tiedoston nimi ennen sen avaamista. Haluatko jatkaa?",
     "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Olet aikeissa siirtyä kohteeseen {host}. Haluatko varmasti jatkaa? Linkki: {link}",
     "Proceed" : "Jatka",
     "No attachments" : "Ei liitteitä",
@@ -357,9 +344,6 @@ OC.L10N.register(
     "Decline" : "Kieltäydy",
     "Tentative" : "Alustava",
     "No attendees yet" : "Ei vielä osallistujia",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} kutsuttu, {confirmedCount} vahvistettu",
-    "Successfully appended link to talk room to description." : "Linkki Talk-huoneeseen lisättiin onnistuneesti kuvaukseen.",
-    "Error creating Talk room" : "Virhe luotaessa Talk-huonetta",
     "Attendees" : "Osallistujat",
     "Remove group" : "Poista ryhmä",
     "Remove attendee" : "Poista osallistuja",
@@ -590,7 +574,6 @@ OC.L10N.register(
     "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
     "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
     "When shared hide this event" : "Jaettaessa piilota tämä tapahtuma",
-    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa.",
     "Add a location" : "Lisää sijainti",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Lisää kuvaus\n\n- Mitä tapaamisessa käsitellään\n- Asialista\n- Mitä hyvänsä mihin osallistujien tulisi valmistautua",
     "Status" : "Tila",
@@ -612,19 +595,38 @@ OC.L10N.register(
     "Attachment {fileName} added!" : "Liite {fileName} lisätty!",
     "An error occurred during uploading file {fileName}" : "Tiedostoa {fileName} lähettäessä tapahtui virhe",
     "An error occurred during getting file information" : "Tiedostojen tietoja noutaessa tapahtui virhe",
-    "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
     "An error occurred, unable to delete the calendar." : "Tapahtui virhe, kalenteria ei voitu poistaa.",
     "Imported {filename}" : "Tuotiin {filename}",
     "This is an event reminder." : "Tämä on tapahtuman muistutus.",
     "Appointment not found" : "Tapaamista ei löydy",
     "User not found" : "Käyttäjää ei löydy",
     "Hidden" : "Piilotettu",
+    "can edit" : "voi muokata",
     "Calendar name …" : "Kalenterin nimi…",
+    "Default attachments location" : "Liitteiden oletussijainti",
     "Automatic ({detected})" : "Automaattinen ({detected})",
     "Shortcut overview" : "Pikakuvakenäkymä",
+    "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
+    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
+    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
     "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
     "Limit the number of events displayed in the monthly view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
+    "Show weekends" : "Näytä viikonloput",
+    "Show week numbers" : "Näytä viikkonumerot",
     "Time increments" : "Aikavälit",
-    "Show keyboard shortcuts" : "Näytä pikanäppäimet"
+    "Default calendar for incoming invitations" : "Oletuskalenteri saapuville kutsuille",
+    "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
+    "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
+    "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
+    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
+    "Create a new public conversation" : "Luo uusi julkinen keskustelu",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} kutsuttu, {confirmedCount} vahvistettu",
+    "Successfully appended link to talk room to description." : "Linkki Talk-huoneeseen lisättiin onnistuneesti kuvaukseen.",
+    "Error creating Talk room" : "Virhe luotaessa Talk-huonetta",
+    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa.",
+    "View options" : "Näkymävalinnat",
+    "Limit number of events shown in month view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
+    "Keyboard shortcuts" : "Pikanäppäimet"
 },
 "nplurals=2; plural=(n != 1);");
