@@ -91,7 +91,6 @@ OC.L10N.register(
     "Delete share link" : "Izbriši poveznicu dijeljenja",
     "Deleting share link …" : "Brisanje poveznice dijeljenja...",
     "An error occurred, unable to change the permission of the share." : "Došlo je do pogreške, nije moguće promijeniti dopuštenje dijeljenja.",
-    "can edit" : "uređivanje moguće",
     "Unshare with {displayName}" : "Prekid dijeljenja s {displayName}",
     "Share with users or groups" : "Dijelite s korisnicima ili grupama",
     "No users or groups" : "Nema korisnika ili grupa",
@@ -104,6 +103,7 @@ OC.L10N.register(
     "Calendar to import into" : "Kalendar za uvoz",
     "Cancel" : "Odustani",
     "_Import calendar_::_Import calendars_" : ["Uvezi kalendar","Uvezi kalendare","Uvezi kalendare"],
+    "Attachments folder" : "Mapa s privicima",
     "{filename} could not be parsed" : "Nije moguće parsirati {filename}",
     "No valid files found, aborting import" : "Nisu pronađene važeće datoteke, uvoz je otkazan",
     "Import partially failed. Imported {accepted} out of {total}." : "Djelomično neuspješan uvoz. Uvezeno {accepted} od {total}.",
@@ -124,18 +124,11 @@ OC.L10N.register(
     "Show shortcuts" : "Prikaži prečace",
     "or" : "ili",
     "No reminder" : "Nema podsjetnika",
-    "CalDAV link copied to clipboard." : "Poveznica kalendara CalDAV kopirana je u međuspremnik.",
-    "CalDAV link could not be copied to clipboard." : "Poveznica kalendara CalDAV nije kopirana u međuspremnik.",
     "General" : "Općenito",
-    "Copy primary CalDAV address" : "Kopiraj primarnu CalDAV adresu",
-    "Copy iOS/macOS CalDAV address" : "Kopiraj iOS/macOS CalDAV adresu",
-    "Enable birthday calendar" : "Omogući kalendar rođendana",
-    "Show tasks in calendar" : "Prikaži zadatke u kalendaru",
-    "Show weekends" : "Prikaži vikende",
-    "Show week numbers" : "Prikaži brojeve tjedana",
+    "Appearance" : "Izgled",
     "Editing" : "Uređivanje",
     "Default reminder" : "Zadani podsjetnik",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Files" : "Datoteke",
     "Update" : "Ažuriraj",
     "Location" : "Lokacija",
     "Description" : "Opis",
@@ -190,8 +183,6 @@ OC.L10N.register(
     "Decline" : "Odbij",
     "Tentative" : "Uvjetno",
     "No attendees yet" : "Još nema sudionika",
-    "Successfully appended link to talk room to description." : "Uspješno dodana poveznica na Talk sobu u opis.",
-    "Error creating Talk room" : "Pogreška pri stvaranju Talk sobe",
     "Attendees" : "Sudionici",
     "Remove group" : "Ukloni grupu",
     "Remove attendee" : "Ukloni sudionika",
@@ -350,7 +341,6 @@ OC.L10N.register(
     "When shared show full event" : "Kada se dijeli, prikaži cijeli događaj",
     "When shared show only busy" : "Kada se dijeli, prikaži samo zauzeto",
     "When shared hide this event" : "Kada se dijeli, sakrij događaj",
-    "The visibility of this event in shared calendars." : "Vidljivost ovog događaja u dijeljenim kalendarima.",
     "Add a location" : "Dodaj lokaciju",
     "Status" : "Status",
     "Confirmed" : "Potvrđeno",
@@ -369,10 +359,23 @@ OC.L10N.register(
     "Imported {filename}" : "Uvezena datoteka {filename}",
     "User not found" : "Korisnik nije pronađen",
     "Hidden" : "Skriveno",
+    "can edit" : "uređivanje moguće",
     "Automatic ({detected})" : "Automatsko ({detected})",
     "Shortcut overview" : "Pregled prečaca",
+    "CalDAV link copied to clipboard." : "Poveznica kalendara CalDAV kopirana je u međuspremnik.",
+    "CalDAV link could not be copied to clipboard." : "Poveznica kalendara CalDAV nije kopirana u međuspremnik.",
+    "Enable birthday calendar" : "Omogući kalendar rođendana",
+    "Show tasks in calendar" : "Prikaži zadatke u kalendaru",
     "Enable simplified editor" : "Omogući jednostavan uređivač",
+    "Show weekends" : "Prikaži vikende",
+    "Show week numbers" : "Prikaži brojeve tjedana",
     "Time increments" : "Vremenski prirasti",
-    "Show keyboard shortcuts" : "Prikaži tipkovne prečace"
+    "Copy primary CalDAV address" : "Kopiraj primarnu CalDAV adresu",
+    "Copy iOS/macOS CalDAV address" : "Kopiraj iOS/macOS CalDAV adresu",
+    "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
+    "Successfully appended link to talk room to description." : "Uspješno dodana poveznica na Talk sobu u opis.",
+    "Error creating Talk room" : "Pogreška pri stvaranju Talk sobe",
+    "The visibility of this event in shared calendars." : "Vidljivost ovog događaja u dijeljenim kalendarima.",
+    "Keyboard shortcuts" : "Tipkovni prečaci"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
