@@ -20,7 +20,6 @@ OC.L10N.register(
     "Restore" : "Restaurar",
     "Delete permanently" : "Deler permanentemente",
     "Share link" : "Compartir ligamine",
-    "can edit" : "pote modificar",
     "Share with users or groups" : "Compartir con usatores o gruppos",
     "Save" : "Salveguardar",
     "View" : "Vider",
@@ -28,8 +27,6 @@ OC.L10N.register(
     "Automatic" : "Automatic",
     "Actions" : "Actiones",
     "General" : "General",
-    "Show week numbers" : "Monstrar le numero del septimanas",
-    "Keyboard shortcuts" : "Combinationes de claves",
     "Update" : "Actualisar",
     "Location" : "Loco",
     "Description" : "Description",
@@ -75,6 +72,9 @@ OC.L10N.register(
     "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
     "When shared hide this event" : "Quando compartite, celar iste evento",
     "Confirmed" : "Confirmate",
-    "Hidden" : "Occultate"
+    "Hidden" : "Occultate",
+    "can edit" : "pote modificar",
+    "Show week numbers" : "Monstrar le numero del septimanas",
+    "Keyboard shortcuts" : "Combinationes de claves"
 },
 "nplurals=2; plural=(n != 1);");
