@@ -155,13 +155,9 @@ OC.L10N.register(
     "Create event" : "Buat acara",
     "Show shortcuts" : "Tampilkan pintasan",
     "or" : "atau",
-    "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
-    "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
     "General" : "Umum",
-    "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
     "Appearance" : "Tampilan",
     "Editing" : "Pengeditan",
-    "Keyboard shortcuts" : "Pintasan keyboard",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
     "_{duration} hour_::_{duration} hours_" : ["{duration} jam"],
     "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat email Anda di pengaturan pribadi.",
@@ -217,8 +213,6 @@ OC.L10N.register(
     "Decline" : "Tolak",
     "Tentative" : "Tentatif",
     "No attendees yet" : "Belum ada peserta",
-    "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
-    "Error creating Talk room" : "Galat membuat ruangan Talk",
     "Attendees" : "Peserta",
     "Remove group" : "Hapus grup",
     "Remove attendee" : "Hapus peserta",
@@ -343,13 +337,19 @@ OC.L10N.register(
     "can edit" : "dapat edit",
     "Automatic ({detected})" : "Otomatis ({detected})",
     "Shortcut overview" : "Ikhtisar pintasan",
+    "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
+    "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
     "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
     "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
     "Enable simplified editor" : "Aktifkan editor serderhana",
     "Show weekends" : "Tampilkan akhir pekan",
     "Show week numbers" : "Tampilkan nomor pekan",
     "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
     "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
-    "The visibility of this event in shared calendars." : "Visibilitas acara ini di kalender yang dibagikan."
+    "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
+    "Error creating Talk room" : "Galat membuat ruangan Talk",
+    "The visibility of this event in shared calendars." : "Visibilitas acara ini di kalender yang dibagikan.",
+    "Keyboard shortcuts" : "Pintasan keyboard"
 },
 "nplurals=1; plural=0;");
