@@ -137,7 +137,6 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Teymi)",
     "An error occurred while unsharing the calendar." : "Villa kom upp við að taka dagatalið úr samnýtingu.",
     "An error occurred, unable to change the permission of the share." : "Villa kom upp, gat ekki breytt heimildum á sameigninni.",
-    "can edit" : "getur breytt",
     "Unshare with {displayName}" : "Hætta deilingu með {displayName}",
     "Share with users or groups" : "Deila með notendum eða hópum",
     "No users or groups" : "Engir notendur eða hópar",
@@ -158,7 +157,6 @@ OC.L10N.register(
     "Invalid location selected" : "Ógild staðsetning valin",
     "Attachments folder successfully saved." : "Tókst að vista viðhengjamöppu.",
     "Error on saving attachments folder." : "Villa við að vista viðhengjamöppu.",
-    "Default attachments location" : "Sjálfgefin staðsetning viðhengja",
     "{filename} could not be parsed" : "Ekki var hægt að þátta {filename}",
     "No valid files found, aborting import" : "Engar gildar skrár fundust, hætti innflutningi",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Það tókst að flytja inn %n atburð","Það tókst að flytja inn %n atburði"],
@@ -189,20 +187,11 @@ OC.L10N.register(
     "At event start" : "Við upphaf atburðar",
     "No reminder" : "Engin áminning",
     "Failed to save default calendar" : "Mistókst að vista sjálfgefið dagatal",
-    "CalDAV link copied to clipboard." : "CalDAV-tengill afritaður á klippispjald.",
-    "CalDAV link could not be copied to clipboard." : "Ekki var hægt að afrita CalDAV-tengil á klippispjald.",
     "General" : "Almennt",
-    "Personal availability settings" : "Persónulegar stillingar varðandi hvenær til taks",
-    "Copy primary CalDAV address" : "Afrita aðal-CalDAV-vistfang",
-    "Copy iOS/macOS CalDAV address" : "Afrita iOS/macOS CalDAV-vistfang ",
-    "Enable birthday calendar" : "Virkja fæðingardagatal",
-    "Show tasks in calendar" : "Sýna verkefni í dagatali",
-    "Show weekends" : "Sýna helgar",
-    "Show week numbers" : "Sýna vikunúmer",
+    "Appearance" : "Útlit",
     "Editing" : "Breytingar",
-    "Default calendar for incoming invitations" : "Sjálfgefið dagatal fyrir boð sem berast",
     "Default reminder" : "Sjálfgefin áminning",
-    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
+    "Files" : "Skráaforrit",
     "Appointment schedule successfully created" : "Tókst að útbúa dagskrá stefnumóta",
     "Appointment schedule successfully updated" : "Tókst að uppfæra dagskrá stefnumóta",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} mínúta","{duration} mínútur"],
@@ -262,6 +251,7 @@ OC.L10N.register(
     "Successfully added Talk conversation link to location." : "Tókst að bæta tengli á samtal á staðsetningu.",
     "Successfully added Talk conversation link to description." : "Tókst að bæta tengli á samtal á lýsingu.",
     "Failed to apply Talk room." : "Mistókst að virkja spjallrás.",
+    "Talk conversation for event" : "Samtal fyrir atburð",
     "Error creating Talk conversation" : "Mistókst að útbúa samtal",
     "Select a Talk Room" : "Veldu spjallrás",
     "Add Talk conversation" : "Bæta við samtali á spjallrás",
@@ -343,12 +333,7 @@ OC.L10N.register(
     "Decline" : "Hafna",
     "Tentative" : "Með fyrirvara",
     "No attendees yet" : "Engir þátttakendur ennþá",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} boðið, {confirmedCount} staðfestir",
-    "Successfully appended link to talk room to location." : "Tókst að bæta tengli á spjallsvæði við staðsetningu.",
-    "Successfully appended link to talk room to description." : "Tókst að bæta tengli á spjallsvæði við lýsingu.",
-    "Error creating Talk room" : "Villa við að búa til spjallsvæði.",
     "Attendees" : "Þátttakendur",
-    "_%n more guest_::_%n more guests_" : ["%n gestur til viðbótar","%n gestir til viðbótar"],
     "Remove group" : "Fjarlægja hóp",
     "Remove attendee" : "Fjarlægja þátttakanda",
     "Request reply" : "Biðja um svar",
@@ -543,7 +528,6 @@ OC.L10N.register(
     "When shared show full event" : "Þegar er deilt, birta allan atburð",
     "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
     "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
-    "The visibility of this event in shared calendars." : "Sýnileiki þessa atburðar í sameiginlegum dagatölum",
     "Add a location" : "Bæta við staðsetningu",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Bættu við lýsingu\n\n- Um hvað snýst þessi fundur\n- Atriði á dagskrá\n- Hvaðeina sem þátttakendur þurfa að undirbúa",
     "Status" : "Staða",
@@ -562,7 +546,6 @@ OC.L10N.register(
     "Error while sharing file with user" : "Villa við deilingu skráar með notanda",
     "Attachment {fileName} already exists!" : "Viðhengið {fileName} er þegar til staðar!",
     "An error occurred during getting file information" : "Villa kom upp við að sækja upplýsingar um skrá",
-    "Talk conversation for event" : "Samtal fyrir atburð",
     "An error occurred, unable to delete the calendar." : "Villa kom upp, gat ekki eytt dagatalinu.",
     "Imported {filename}" : "Flutti inn {filename}",
     "This is an event reminder." : "Þetta er áminning vegna atburðar.",
@@ -570,12 +553,31 @@ OC.L10N.register(
     "Appointment not found" : "Stefnumót fannst ekki",
     "User not found" : "Notandi fannst ekki",
     "Hidden" : "Falinn",
+    "can edit" : "getur breytt",
     "Calendar name …" : "Heiti dagatals …",
+    "Default attachments location" : "Sjálfgefin staðsetning viðhengja",
     "Automatic ({detected})" : "Sjálfvirkt ({detected})",
     "Shortcut overview" : "Yfirlit flýtilykla",
+    "CalDAV link copied to clipboard." : "CalDAV-tengill afritaður á klippispjald.",
+    "CalDAV link could not be copied to clipboard." : "Ekki var hægt að afrita CalDAV-tengil á klippispjald.",
+    "Enable birthday calendar" : "Virkja fæðingardagatal",
+    "Show tasks in calendar" : "Sýna verkefni í dagatali",
     "Enable simplified editor" : "Virkja einfaldaðan ritil",
     "Limit the number of events displayed in the monthly view" : "Takmarka fjölda atburða sem birtast í mánaðaryfirlitinu",
+    "Show weekends" : "Sýna helgar",
+    "Show week numbers" : "Sýna vikunúmer",
     "Time increments" : "Tímaþrep",
-    "Show keyboard shortcuts" : "Birta flýtivísanir á lyklaborði"
+    "Default calendar for incoming invitations" : "Sjálfgefið dagatal fyrir boð sem berast",
+    "Copy primary CalDAV address" : "Afrita aðal-CalDAV-vistfang",
+    "Copy iOS/macOS CalDAV address" : "Afrita iOS/macOS CalDAV-vistfang ",
+    "Personal availability settings" : "Persónulegar stillingar varðandi hvenær til taks",
+    "Show keyboard shortcuts" : "Birta flýtivísanir á lyklaborði",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} boðið, {confirmedCount} staðfestir",
+    "Successfully appended link to talk room to location." : "Tókst að bæta tengli á spjallsvæði við staðsetningu.",
+    "Successfully appended link to talk room to description." : "Tókst að bæta tengli á spjallsvæði við lýsingu.",
+    "Error creating Talk room" : "Villa við að búa til spjallsvæði.",
+    "_%n more guest_::_%n more guests_" : ["%n gestur til viðbótar","%n gestir til viðbótar"],
+    "The visibility of this event in shared calendars." : "Sýnileiki þessa atburðar í sameiginlegum dagatölum",
+    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
