@@ -136,7 +136,6 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
     "An error occurred while unsharing the calendar." : "カレンダーの共有解除中にエラーが発生しました",
     "An error occurred, unable to change the permission of the share." : "エラーが発生したため、共有の権限を変更できませんでした。",
-    "can edit" : "編集を許可",
     "Unshare with {displayName}" : "{displayName}との共有を解除",
     "Share with users or groups" : "ユーザーまたはグループと共有する",
     "No users or groups" : "ユーザーまたはグループはありません",
@@ -145,6 +144,7 @@ OC.L10N.register(
     "Share calendar" : "カレンダー共有",
     "Unshare from me" : "共有を自分から解除",
     "Save" : "保存",
+    "Are you sure you want to delete \"{title}\"?" : "本当に\"{title}\"を削除してもいいですか?",
     "View" : "表示",
     "Import calendars" : "カレンダーのインポート",
     "Please select a calendar to import into …" : "インポートするカレンダーを選択してください …",
@@ -157,7 +157,7 @@ OC.L10N.register(
     "Invalid location selected" : "選択した場所が無効",
     "Attachments folder successfully saved." : "添付ファイルフォルダーを保存しました",
     "Error on saving attachments folder." : "添付ファイルフォルダーの保存でエラーが発生しました",
-    "Default attachments location" : "添付ファイルのデフォルト位置",
+    "Attachments folder" : "添付ファイルフォルダー",
     "{filename} could not be parsed" : "{filename} が解析できませんでした",
     "No valid files found, aborting import" : "有効なファイルが見つかりませんでした。インポートを中止します。",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%nイベントのインポートに成功しました"],
@@ -188,20 +188,11 @@ OC.L10N.register(
     "At event start" : "イベント開始時",
     "No reminder" : "リマインダーなし",
     "Failed to save default calendar" : "デフォルトカレンダーの保存に失敗しました",
-    "CalDAV link copied to clipboard." : "CalDAVリンクがクリップボードにコピーされました",
-    "CalDAV link could not be copied to clipboard." : "CalDAVリンクをクリップボードにコピーできませんでした",
     "General" : "一般",
-    "Personal availability settings" : "個人の稼働率設定",
-    "Copy primary CalDAV address" : "通常のCalDAVアドレスをコピー",
-    "Copy iOS/macOS CalDAV address" : "iOS/macOS用のCalDAVアドレスをコピー",
-    "Enable birthday calendar" : "誕生日カレンダーを有効にする",
-    "Show tasks in calendar" : "カレンダーにタスクを表示",
-    "Show weekends" : "週末を表示する",
-    "Show week numbers" : "週番号を表示する",
+    "Appearance" : "表示",
     "Editing" : "編集中",
-    "Default calendar for incoming invitations" : "受信した招待状のデフォルトカレンダー",
     "Default reminder" : "既定のリマインダー",
-    "Keyboard shortcuts" : "キーボードショートカット",
+    "Files" : "ファイル",
     "Appointment schedule successfully created" : "予約スケジュールの作成に成功しました",
     "Appointment schedule successfully updated" : "予約スケジュールの更新に成功しました",
     "_{duration} minute_::_{duration} minutes_" : ["{duration}分"],
@@ -252,7 +243,8 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "会議の準備に役立つことがあれば教えてください。",
     "Could not book the appointment. Please try again later or contact the organizer." : "予約できませんでした。後でもう一度試してみるか、主催者に連絡してください。",
     "Back" : "戻る",
-    "Create a new public conversation" : "公開の会話を作成する",
+    "Successfully added Talk conversation link to location." : "トークへのリンクをロケーションに追加しました。",
+    "Add Talk conversation" : "会話を追加",
     "Select conversation" : "会話を選択",
     "on" : "曜日",
     "at" : "で",
@@ -325,12 +317,7 @@ OC.L10N.register(
     "Decline" : "拒否",
     "Tentative" : "暫定的",
     "No attendees yet" : "出席者はまだいません",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} 招待済み, {confirmedCount} 確定",
-    "Successfully appended link to talk room to location." : "トークルームへのリンクをロケーションに追加しました。",
-    "Successfully appended link to talk room to description." : "通話ルームへのリンクを説明文に追加しました",
-    "Error creating Talk room" : "通話ルームの作成に失敗しました",
     "Attendees" : "参加者",
-    "_%n more guest_::_%n more guests_" : ["ゲスト %n 名追加"],
     "Remove group" : "グループを削除",
     "Remove attendee" : "出席者を削除",
     "Request reply" : "返信をリクエストする",
@@ -348,8 +335,9 @@ OC.L10N.register(
     "Event title" : "イベントタイトル",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "繰り返しの一部であるイベントの終日設定は変更できません。",
     "From" : "開始",
-    "To" : "宛先",
+    "To" : "終了",
     "Repeat" : "繰り返し",
+    "Repeat event" : "繰り返しイベント",
     "_time_::_times_" : ["回数"],
     "never" : "なし",
     "on date" : "日時指定",
@@ -529,7 +517,6 @@ OC.L10N.register(
     "When shared show full event" : "共有時にすべてのイベントを表示",
     "When shared show only busy" : "共有時に実行中のみを表示",
     "When shared hide this event" : "共有時にこのイベントを隠す",
-    "The visibility of this event in shared calendars." : "共有カレンダーでのこのイベントの表示。",
     "Add a location" : "住所を追加",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "説明を追加\n\n- この会議の目的\n- 議題\n- 参加者が準備する必要があるもの",
     "Status" : "ステータス",
@@ -554,12 +541,32 @@ OC.L10N.register(
     "Appointment not found" : "予定が見つかりません",
     "User not found" : "ユーザーが見つかりません",
     "Hidden" : "非公開",
+    "can edit" : "編集を許可",
     "Calendar name …" : "カレンダー名 …",
+    "Default attachments location" : "添付ファイルのデフォルト位置",
     "Automatic ({detected})" : "自動 ({detected})",
     "Shortcut overview" : "概要",
+    "CalDAV link copied to clipboard." : "CalDAVリンクがクリップボードにコピーされました",
+    "CalDAV link could not be copied to clipboard." : "CalDAVリンクをクリップボードにコピーできませんでした",
+    "Enable birthday calendar" : "誕生日カレンダーを有効にする",
+    "Show tasks in calendar" : "カレンダーにタスクを表示",
     "Enable simplified editor" : "簡易エディターを有効にする",
     "Limit the number of events displayed in the monthly view" : "月間ビューに表示されるイベント数を制限する",
+    "Show weekends" : "週末を表示する",
+    "Show week numbers" : "週番号を表示する",
     "Time increments" : "時間の増加",
-    "Show keyboard shortcuts" : "キーボード ショートカット"
+    "Default calendar for incoming invitations" : "受信した招待状のデフォルトカレンダー",
+    "Copy primary CalDAV address" : "通常のCalDAVアドレスをコピー",
+    "Copy iOS/macOS CalDAV address" : "iOS/macOS用のCalDAVアドレスをコピー",
+    "Personal availability settings" : "個人の稼働率設定",
+    "Show keyboard shortcuts" : "キーボード ショートカット",
+    "Create a new public conversation" : "公開の会話を作成",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} 招待済み, {confirmedCount} 確定",
+    "Successfully appended link to talk room to location." : "トークルームへのリンクをロケーションに追加しました。",
+    "Successfully appended link to talk room to description." : "通話ルームへのリンクを説明文に追加しました",
+    "Error creating Talk room" : "通話ルームの作成に失敗しました",
+    "_%n more guest_::_%n more guests_" : ["ゲスト %n 名追加"],
+    "The visibility of this event in shared calendars." : "共有カレンダーでのこのイベントの表示。",
+    "Keyboard shortcuts" : "キーボードショートカット"
 },
 "nplurals=1; plural=0;");
