@@ -180,14 +180,11 @@ OC.L10N.register(
     "or" : "또는",
     "Calendar settings" : "달력 설정",
     "No reminder" : "알림 없음",
-    "CalDAV link copied to clipboard." : "CalDAV 링크를 클립보드에 복사했습니다.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV 링크를 클립보드에 복사할 수 없습니다.",
     "General" : "일반",
-    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV 주소 복사하기",
     "Appearance" : "외형",
     "Editing" : "글 수정",
     "Default reminder" : "기본 알림",
-    "Keyboard shortcuts" : "키보드 단축키",
+    "Files" : "파일",
     "Appointment schedule successfully created" : "약속 일정이 성공적으로 생성되었습니다",
     "Appointment schedule successfully updated" : "약속 일정이 성공적으로 갱신되었습니다",
     "_{duration} minute_::_{duration} minutes_" : ["{duration}분"],
@@ -301,9 +298,6 @@ OC.L10N.register(
     "Decline" : "거절",
     "Tentative" : "예정됨",
     "No attendees yet" : "아직 참석자가 없습니다.",
-    "Successfully appended link to talk room to location." : "위치에 대화방 링크를 성공적으로 추가함",
-    "Successfully appended link to talk room to description." : "설명에 대화방 링크를 성공적으로 추가함",
-    "Error creating Talk room" : "대화방 생성 오류",
     "Attendees" : "참석자",
     "Remove group" : "그룹 지우기",
     "Remove attendee" : "참석자 삭제",
@@ -514,6 +508,8 @@ OC.L10N.register(
     "Default attachments location" : "기본 첨부파일 위치",
     "Automatic ({detected})" : "자동 ({detected})",
     "Shortcut overview" : "바로가기 개요",
+    "CalDAV link copied to clipboard." : "CalDAV 링크를 클립보드에 복사했습니다.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV 링크를 클립보드에 복사할 수 없습니다.",
     "Enable birthday calendar" : "생일 달력 활성화",
     "Show tasks in calendar" : "달력에 작업 보이기",
     "Enable simplified editor" : "간편한 편집기 활성화",
@@ -522,8 +518,13 @@ OC.L10N.register(
     "Show week numbers" : "주 번호 보이기",
     "Time increments" : "시간 단위",
     "Copy primary CalDAV address" : "주 CalDAV 주소 복사하기",
+    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV 주소 복사하기",
     "Personal availability settings" : "개인별 시간 조율 설정",
     "Show keyboard shortcuts" : "키보드 단축키 표시",
-    "The visibility of this event in shared calendars." : "공유 달력에서 이 일정의 표시 여부"
+    "Successfully appended link to talk room to location." : "위치에 대화방 링크를 성공적으로 추가함",
+    "Successfully appended link to talk room to description." : "설명에 대화방 링크를 성공적으로 추가함",
+    "Error creating Talk room" : "대화방 생성 오류",
+    "The visibility of this event in shared calendars." : "공유 달력에서 이 일정의 표시 여부",
+    "Keyboard shortcuts" : "키보드 단축키"
 },
 "nplurals=1; plural=0;");
