@@ -94,7 +94,6 @@ OC.L10N.register(
     "Delete permanently" : "Ištrinti negrįžtamai",
     "Could not update calendar order." : "Nepavyko atnaujinti kalendoriaus tvarkos.",
     "Deck" : "Darbai",
-    "Hidden" : "Paslėpta",
     "Internal link" : "Vidinė nuoroda",
     "Copy internal link" : "Kopijuoti vidinę nuorodą",
     "An error occurred, unable to publish calendar." : "Įvyko klaida, nepavyko paskelbti kalendoriaus.",
@@ -115,12 +114,10 @@ OC.L10N.register(
     "Deleting share link …" : "Ištrinama viešinio nuoroda …",
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Komanda)",
     "An error occurred, unable to change the permission of the share." : "Įvykio klaida, nepavyko pakeisti viešinio leidimo.",
-    "can edit" : "gali redaguoti",
     "Unshare with {displayName}" : "Nustoti bendrinti su {displayName}",
     "Share with users or groups" : "Bendrinti su naudotojais ar grupėmis",
     "No users or groups" : "Nėra jokių naudotojų ar grupių",
     "Failed to save calendar name and color" : "Nepavyko įrašyti kalendoriaus pavadinimo ir spalvos",
-    "Calendar name …" : "Kalendoriaus pavadinimas…",
     "Share calendar" : "Bendrinti kalendorių",
     "Unshare from me" : "Nustoti bendrinti su manimi",
     "Save" : "Įrašyti",
@@ -134,14 +131,15 @@ OC.L10N.register(
     "Invalid location selected" : "Pasirinkta neteisinga vieta",
     "Attachments folder successfully saved." : "Priedų aplankas sėkmingai įrašytas.",
     "Error on saving attachments folder." : "Klaida įrašant priedų aplanką.",
-    "Default attachments location" : "Numatytoji priedų vieta",
+    "Attachments folder" : "Priedų aplankas",
     "{filename} could not be parsed" : "Nepavyko išnagrinėti {filename}",
     "No valid files found, aborting import" : "Nerasta jokių tinkamų failų, importavimas nutraukiamas",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Sėkmingai importuotas %n įvykis","Sėkmingai importuoti %n įvykiai","Sėkmingai importuota %n įvykių","Sėkmingai importuotas %n įvykis"],
     "Import partially failed. Imported {accepted} out of {total}." : "Importavimas dalinai nepavyko. Importuota {accepted} iš {total}.",
     "Automatic" : "Automatinė",
-    "Automatic ({detected})" : "Automatinė ({detected})",
+    "Automatic ({timezone})" : "Automatinė ({timezone})",
     "New setting was not saved successfully." : "Naujas nustatymas nebuvo sėkmingai įrašytas.",
+    "Timezone" : "Laiko juosta",
     "Navigation" : "Navigacija",
     "Previous period" : "Ankstesnis laikotarpis",
     "Next period" : "Kitas laikotarpis",
@@ -159,24 +157,15 @@ OC.L10N.register(
     "Save edited event" : "Įrašyti taisytą įvykį",
     "Delete edited event" : "Ištrinti taisytą įvykį",
     "Duplicate event" : "Dubliuoti įvykį",
-    "Shortcut overview" : "Nuorodų apžvalga",
     "or" : "ar",
     "Calendar settings" : "Kalendoriaus nustatymai",
     "No reminder" : "Jokio priminimo",
     "Failed to save default calendar" : "Nepavyko įrašyti numatytojo kalendoriaus",
-    "CalDAV link copied to clipboard." : "CalDAV nuoroda nukopijuota į iškarpinę.",
-    "CalDAV link could not be copied to clipboard." : "Nepavyko nukopijuoti CalDAV nuorodą į iškarpinę.",
-    "Enable birthday calendar" : "Įjungti gimtadienių kalendorių",
-    "Show tasks in calendar" : "Rodyti užduotis kalendoriuje",
-    "Enable simplified editor" : "Įjungti supaprastintą redaktorių",
-    "Limit the number of events displayed in the monthly view" : "Riboti mėnesio rodinyje rodomų įvykių skaičių",
-    "Show weekends" : "Rodyti savaitgalius",
-    "Show week numbers" : "Rodyti savaičių numerius",
+    "General" : "Bendra",
+    "Appearance" : "Išvaizda",
+    "Editing" : "Taisymas",
     "Default reminder" : "Numatytasis priminimas",
-    "Copy primary CalDAV address" : "Kopijuoti pirminį CalDAV adresą",
-    "Copy iOS/macOS CalDAV address" : "Kopijuoti iOS/macOS CalDAV adresą",
-    "Personal availability settings" : "Asmeninio pasiekiamumo nustatymai",
-    "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
+    "Files" : "Failai",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minutė","{duration} minutės","{duration} minučių","{duration} minutė"],
     "0 minutes" : "0 minučių",
     "_{duration} hour_::_{duration} hours_" : ["{duration} valanda","{duration} valandos","{duration} valandų","{duration} valanda"],
@@ -232,6 +221,7 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Pasirinkite failą, kurį prisegsite prie laiško",
     "Choose a file to share as a link" : "Pasirinkite failą, kurį bendrinsite kaip nuorodą",
     "Add from Files" : "Pridėti iš Failų",
+    "Upload from device" : "Įkelti iš įrenginio",
     "Delete file" : "Ištrinti failą",
     "_{count} attachment_::_{count} attachments_" : ["{count} priedas","{count} priedai","{count} priedų","{count} priedas"],
     "Available" : "Prieinamas",
@@ -254,8 +244,6 @@ OC.L10N.register(
     "Decline" : "Atmesti",
     "Tentative" : "Preliminarus",
     "No attendees yet" : "Kol kas kviestinių nėra",
-    "Successfully appended link to talk room to description." : "Pokalbių kambario nuoroda sėkmingai pridėta į aprašą.",
-    "Error creating Talk room" : "Klaida sukuriant pokalbių kambarį",
     "Attendees" : "Kviestiniai",
     "Remove group" : "Šalinti grupę",
     "Remove attendee" : "Šalinti kviestinį",
@@ -314,7 +302,10 @@ OC.L10N.register(
     "Update this occurrence" : "Atnaujinti šį pasikartojimą",
     "Public calendar does not exist" : "Viešojo kalendoriaus nėra",
     "Maybe the share was deleted or has expired?" : "Galbūt, viešinys buvo ištrintas arba nebegalioja?",
+    "Yes" : "Taip",
+    "No" : "Ne",
     "Maybe" : "Galbūt",
+    "None" : "Nėra",
     "Create" : "Sukurti",
     "from {formattedDate}" : "nuo {formattedDate}",
     "to {formattedDate}" : "iki {formattedDate}",
@@ -346,7 +337,9 @@ OC.L10N.register(
     "Untitled event" : "Įvykis be pavadinimo",
     "Close" : "Užverti",
     "Selected" : "Pasirinkta",
+    "Title" : "Pavadinimas",
     "Participants" : "Dalyviai",
+    "Submit" : "Pateikti",
     "Subscribe to {name}" : "Prenumeruoti {name}",
     "Export {name}" : "Eksportuoti {name}",
     "Show availability" : "Rodyti prieinamumą",
@@ -414,7 +407,6 @@ OC.L10N.register(
     "When shared show full event" : "Bendrinant, rodyti visą įvykio informaciją",
     "When shared show only busy" : "Bendrinant, rodyti tik kaip užimtą laiką",
     "When shared hide this event" : "Bendrinant, slėpti šį įvykį",
-    "The visibility of this event in shared calendars." : "Šio įvykio matomumas bendrinamuose kalendoriuose.",
     "Add a location" : "Pridėti vietą",
     "Status" : "Būsena",
     "Confirmed" : "Patvirtintas",
@@ -436,6 +428,28 @@ OC.L10N.register(
     "Imported {filename}" : "Importuotas {filename}",
     "This is an event reminder." : "Tai priminimas apie įvykį.",
     "Appointment not found" : "Susitikimas nerastas",
-    "User not found" : "Naudotojas nerastas"
+    "User not found" : "Naudotojas nerastas",
+    "Hidden" : "Paslėpta",
+    "can edit" : "gali redaguoti",
+    "Calendar name …" : "Kalendoriaus pavadinimas…",
+    "Default attachments location" : "Numatytoji priedų vieta",
+    "Automatic ({detected})" : "Automatinė ({detected})",
+    "Shortcut overview" : "Nuorodų apžvalga",
+    "CalDAV link copied to clipboard." : "CalDAV nuoroda nukopijuota į iškarpinę.",
+    "CalDAV link could not be copied to clipboard." : "Nepavyko nukopijuoti CalDAV nuorodą į iškarpinę.",
+    "Enable birthday calendar" : "Įjungti gimtadienių kalendorių",
+    "Show tasks in calendar" : "Rodyti užduotis kalendoriuje",
+    "Enable simplified editor" : "Įjungti supaprastintą redaktorių",
+    "Limit the number of events displayed in the monthly view" : "Riboti mėnesio rodinyje rodomų įvykių skaičių",
+    "Show weekends" : "Rodyti savaitgalius",
+    "Show week numbers" : "Rodyti savaičių numerius",
+    "Copy primary CalDAV address" : "Kopijuoti pirminį CalDAV adresą",
+    "Copy iOS/macOS CalDAV address" : "Kopijuoti iOS/macOS CalDAV adresą",
+    "Personal availability settings" : "Asmeninio pasiekiamumo nustatymai",
+    "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
+    "Successfully appended link to talk room to description." : "Pokalbių kambario nuoroda sėkmingai pridėta į aprašą.",
+    "Error creating Talk room" : "Klaida sukuriant pokalbių kambarį",
+    "The visibility of this event in shared calendars." : "Šio įvykio matomumas bendrinamuose kalendoriuose.",
+    "Keyboard shortcuts" : "Spartieji klavišai"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
