@@ -7,7 +7,7 @@ OC.L10N.register(
     "%s has published the calendar »%s«" : "%s dalījās ar kalendāru »%s«",
     "Unexpected error sending email. Please contact your administrator." : "E-pasta ziņojuma nosūtīšanas laikā bija neparedzēta kļūda. Lūgums sazināties ar savu pārvaldītāju.",
     "Successfully sent email to %1$s" : "E-pasta ziņojums sekmīgi nosūtīts uz %1$s",
-    "Hello," : "Sveicināti,",
+    "Hello," : "Sveiciens,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Mēs vēlējāmies ziņot, ka %s padarīja pieejamu kalendāru »%s«.",
     "Open »%s«" : "Atvērt »%s«",
     "Cheers!" : "Priekā!",
@@ -105,7 +105,7 @@ OC.L10N.register(
     "Restore" : "Atjaunot",
     "Delete permanently" : "Neatgriezeniski izdzēst",
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Atkritnes vienumi tiek izdzēsti pēc {numDays} dienām","Atkritnes vienumi tiek izdzēsti pēc {numDays} dienas","Atkritnes vienumi tiek izdzēsti pēc {numDays} dienām"],
-    "Could not update calendar order." : "Nevarēja atjaunināt kalendāra pasūtījumu.",
+    "Could not update calendar order." : "Nevarēja atjaunināt kalendāru secību.",
     "Internal link" : "Iekšējā saite",
     "A private link that can be used with external clients" : "Privāta saite, kas var tikt izmantota ar ārējiem klientiem.",
     "Copy internal link" : "Ievietot iekšējo saiti starpliktuvē",
@@ -126,7 +126,6 @@ OC.L10N.register(
     "Deleting share link …" : "Dzēš koplietoto saiti ...",
     "An error occurred while unsharing the calendar." : "Atgadījās kļūda kalendāra koplietošanas atcelšanas laikā.",
     "An error occurred, unable to change the permission of the share." : "Atgadījās kļūda, nevar mainīt kopīgojuma atļauju.",
-    "can edit" : "var labot",
     "Unshare with {displayName}" : "Atcelt kopīgošanu ar {displayName}",
     "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
     "No users or groups" : "Nav lietotāji vai grupas",
@@ -145,7 +144,6 @@ OC.L10N.register(
     "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta ",
     "Attachments folder successfully saved." : "Pielikumu mape saglabāta sekmīgi.",
     "Error on saving attachments folder." : "Kļūda saglabājot pielikumu mapi.",
-    "Default attachments location" : "Pielikumu noklusējuma atrašanās vietas",
     "No valid files found, aborting import" : "Nav atrastas derīgas datnes, ievietošana tiek pārtraukta.",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Sekmīgi ievietoti %n notikumi","Sekmīgi ievietots %n notikums","Sekmīgi ievietoti %n notikumi"],
     "Import partially failed. Imported {accepted} out of {total}." : "Ievietošana daļēji neizdevās. Ievietoti {accepted} no {total}.",
@@ -174,19 +172,11 @@ OC.L10N.register(
     "Calendar settings" : "Kalendāra iestatījumi",
     "No reminder" : "Nav atgādinājuma",
     "Failed to save default calendar" : "Neizdevās saglabāt noklusējuma kalendāru",
-    "CalDAV link copied to clipboard." : "Kalendāra saite ievietota starpliktuvē.",
-    "CalDAV link could not be copied to clipboard." : "Kalendāra saiti neizdevās ievietot starpliktuvē.",
     "General" : "Vispārīgi",
-    "Personal availability settings" : "Personiskās pieejamības iestatījumi",
-    "Copy primary CalDAV address" : "Ievietot starpliktuvē galveno CalDAV adresi",
-    "Copy iOS/macOS CalDAV address" : "Kopēt IOS/macOS CalDAV adresi",
-    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
-    "Show tasks in calendar" : "Rādīt uzdevumus kalendārā",
-    "Show weekends" : "Rādīt nedēļas nogales",
-    "Show week numbers" : "Rādīt nedēļu numurus",
+    "Appearance" : "Izskats",
     "Editing" : "Labošana",
     "Default reminder" : "Noklusējuma atgādinājums",
-    "Keyboard shortcuts" : "Tastatūras saīsnes",
+    "Files" : "Datnes",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minūšu","{duration} minūte","{duration} minūtes"],
     "0 minutes" : "0 minūtes",
     "_{duration} hour_::_{duration} hours_" : ["{duration} stundu","{duration} stunda","{duration} stundas"],
@@ -289,8 +279,6 @@ OC.L10N.register(
     "Decline" : "Noraidīt",
     "Tentative" : "Mēģinājums",
     "No attendees yet" : "Vēl nav dalībnieku",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uzaicināti, {confirmedCount} apstiprinājuši",
-    "Error creating Talk room" : "Notika kļūda, veidojot tērzēšanas istabu",
     "Attendees" : "Dalībnieki",
     "Remove group" : "Noņemt grupu",
     "Remove attendee" : "Noņemt dalībnieku",
@@ -440,7 +428,6 @@ OC.L10N.register(
     "When shared show full event" : "Ja kopīgots, tad rādīt pilnu notikumu",
     "When shared show only busy" : "Ja kopīgots, tad rādīt tikai aizņemtos",
     "When shared hide this event" : "Ja kopīgots, tad paslēpt šo notikumu",
-    "The visibility of this event in shared calendars." : "Šī notikuma redzamība koplietotos kalendāros.",
     "Add a location" : "Pievienot atrašanās vietu",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Pievienot aprakstu\n\n- Par ko ir šī tikšanās\n- Darba kārtības vienumi\n- Jebkas, kam dalībniekiem ir jāsagatavojas",
     "Status" : "Status",
@@ -465,11 +452,26 @@ OC.L10N.register(
     "Appointment not found" : "Tikšanās nav atrasta",
     "User not found" : "Lietotājs nav atrasts",
     "Hidden" : "Paslēpts",
+    "can edit" : "var labot",
     "Calendar name …" : "Kalendāra nosaukums ...",
+    "Default attachments location" : "Pielikumu noklusējuma atrašanās vietas",
     "Automatic ({detected})" : "Automātiska ({detected})",
     "Shortcut overview" : "Īsceļu pārskats",
+    "CalDAV link copied to clipboard." : "Kalendāra saite ievietota starpliktuvē.",
+    "CalDAV link could not be copied to clipboard." : "Kalendāra saiti neizdevās ievietot starpliktuvē.",
+    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
+    "Show tasks in calendar" : "Rādīt uzdevumus kalendārā",
     "Enable simplified editor" : "Iespējot vienkāršoto redaktoru",
     "Limit the number of events displayed in the monthly view" : "Ierobežot notikumu skaitu, kas tiek parādīti mēneša skatā",
-    "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus"
+    "Show weekends" : "Rādīt nedēļas nogales",
+    "Show week numbers" : "Rādīt nedēļu numurus",
+    "Copy primary CalDAV address" : "Ievietot starpliktuvē galveno CalDAV adresi",
+    "Copy iOS/macOS CalDAV address" : "Kopēt IOS/macOS CalDAV adresi",
+    "Personal availability settings" : "Personiskās pieejamības iestatījumi",
+    "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uzaicināti, {confirmedCount} apstiprinājuši",
+    "Error creating Talk room" : "Notika kļūda, veidojot tērzēšanas istabu",
+    "The visibility of this event in shared calendars." : "Šī notikuma redzamība koplietotos kalendāros.",
+    "Keyboard shortcuts" : "Tastatūras saīsnes"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
