@@ -44,6 +44,9 @@ OC.L10N.register(
     "%s has proposed a meeting" : "%s предложи состанок",
     "%s has updated a proposed meeting" : "%s го ажурираше предложениот состанок",
     "%s has canceled a proposed meeting" : "%s го откажа предложениот состанок",
+    "Dear %s, a new meeting has been proposed" : "Почитуван/а %s, предложен е нов состанок",
+    "Dear %s, a proposed meeting has been updated" : "Почитуван/а %s, предложениот состанок е ажуриран",
+    "Dear %s, a proposed meeting has been cancelled" : "Почитуван/а %s, предложениот состанок е откажан",
     "Location:" : "Локација:",
     "Duration:" : "Времетраење:",
     "%1$s from %2$s to %3$s" : "%1$s од %2$s до %3$s",
@@ -144,7 +147,7 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Тим)",
     "An error occurred while unsharing the calendar." : "Настана грешка при откажување на споделување на календар.",
     "An error occurred, unable to change the permission of the share." : "Настана грешка, неможе да се променат дозволите за споделување.",
-    "can edit" : "може да се измени",
+    "can edit and see confidential events" : "може да уредува и гледа доверливи настани",
     "Unshare with {displayName}" : "Не споделувај со {displayName}",
     "Share with users or groups" : "Сподели со корисници или групи",
     "No users or groups" : "Нема корисници или групи",
@@ -159,7 +162,9 @@ OC.L10N.register(
     "Deleting proposal \"{title}\"" : "Бришење на предлогот \"{title}\"",
     "Successfully deleted proposal" : "Успешно бришење на предлог",
     "Failed to delete proposal" : "Неуспешно бришење на предлог",
+    "Failed to retrieve proposals" : "Не успеа да се преземат предлозите",
     "Meeting proposals" : "Предлози за состаноци",
+    "A configured email address is required to use meeting proposals" : "Потребно е да имате поставено е-пошта адреса за користење на предлози за состаноци",
     "No active meeting proposals" : "Нема активен предлог за состаноци",
     "View" : "Поглед",
     "Import calendars" : "Увези календари",
@@ -173,7 +178,7 @@ OC.L10N.register(
     "Invalid location selected" : "Избрана невалидна локација",
     "Attachments folder successfully saved." : "Папката за прилози е успешно зачувана.",
     "Error on saving attachments folder." : "Грешка при зачувување на папка за прилози.",
-    "Default attachments location" : "Стандардна локација за прилози",
+    "Attachments folder" : "Папка со прилози",
     "{filename} could not be parsed" : "Датотеката {filename} не може да се анализира",
     "No valid files found, aborting import" : "Не е пронајдена валидна датотека, увозот е откажан",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Успешно увезен 1 настан","Успешно увезени %n настани"],
@@ -204,20 +209,23 @@ OC.L10N.register(
     "At event start" : "На почетокот на настанот",
     "No reminder" : "Нема потсетник",
     "Failed to save default calendar" : "Неуспешно зачувување на стандарден календар",
-    "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
     "General" : "Општо",
-    "Personal availability settings" : "Параметри за лична достапност",
-    "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
-    "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
-    "View options" : "Прегледај опции ",
-    "Enable birthday calendar" : "Овозможи календар со родендени",
-    "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
-    "Show weekends" : "Прикажи викенди",
-    "Show week numbers" : "Прикажи броеви на неделите",
-    "Default calendar for incoming invitations" : "Стандарден календар за дојдовни покани",
+    "Availability settings" : "Поставки за достапност",
+    "CalDAV" : "CalDAV",
+    "Access Nextcloud calendars from other apps and devices" : "Пристапете до Nextcloud календарите од други апликации и уреди",
+    "CalDAV URL" : "CalDAV URL",
+    "Appearance" : "Изглед",
+    "Birthday calendar" : "Календар со родендени",
+    "Tasks in calendar" : "Задачи во календарот",
+    "Weekends" : "Викенди",
+    "Week numbers" : "Броеви на недели",
+    "Limit number of events shown in Month view" : "Ограничи го бројот на прикажани настани во преглед по месец",
+    "Density in Day and Week View" : "Густина во дневен и неделен преглед",
+    "Editing" : "Уредување",
     "Default reminder" : "Стандарден потсетник",
-    "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Simple event editor" : "Едноставен уредувач на настани",
+    "\"More details\" opens the detailed editor" : "\"Повеќе детали\" го отвора деталниот уредувач",
+    "Files" : "Датотеки",
     "Appointment schedule successfully created" : "Распоред за состаноци е успешно креиран",
     "Appointment schedule successfully updated" : "Распоред за состаноци е успешно ажуриран",
     "_{duration} minute_::_{duration} minutes_" : ["1 минута","{duration} минути"],
@@ -263,6 +271,7 @@ OC.L10N.register(
     "Minimum time before next available slot" : "Минимално време пред следниот достапен термин",
     "Max slots per day" : "Максимален број термини на ден",
     "Limit how far in the future appointments can be booked" : "Ограничете колку во иднина може да се резервираат термини",
+    "It seems a rate limit has been reached. Please try again later." : "Изгледа е достигнат лимит на барања. Обидете се повторно подоцна.",
     "Please confirm your reservation" : "Ве молиме потврдете ја вашата резервација",
     "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ви испративме е-пошта со детали. Ве молиме потврдете го вашиот термин користејќи ја врската во е-поштата. Можете да ја затворите оваа страница сега.",
     "Your name" : "Вашето име",
@@ -271,6 +280,18 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "Не може да се резервира термин. Обидете се повторно подоцна или контактирајте со организаторот.",
     "Back" : "Назад",
     "Book appointment" : "Резервирај состанок",
+    "Error fetching Talk conversations." : "Грешка при преземање на Talk разговорите.",
+    "Conversation does not have a valid URL." : "Разговорот нема важечка URL адреса.",
+    "Successfully added Talk conversation link to location." : "Успешно додадена врска до Talk разговор во локацијата.",
+    "Successfully added Talk conversation link to description." : "Успешно додадена врска до Talk разговор во описот.",
+    "Failed to apply Talk room." : "Не успеа примената на Talk собата.",
+    "Talk conversation for event" : "Talk разговор за настанот",
+    "Error creating Talk conversation" : "Грешка при создавање на Talk разговор.",
+    "Select a Talk Room" : "Изберете Talk соба",
+    "Add Talk conversation" : "Додај Talk разговор",
+    "Fetching Talk rooms…" : "Се преземаат Talk соби…",
+    "No Talk room available" : "Нема достапни Talk соби",
+    "Create public conversation" : "Создај јавен разговор",
     "Select conversation" : "Избери разговор",
     "on" : "во",
     "at" : "во",
@@ -294,6 +315,8 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
     "Attachment {name} already exist!" : "Прилогот {name} веќе постои!",
     "Could not upload attachment(s)" : "Неможе да се прикачи прилог",
+    "You are about to navigate to {link}. Are you sure to proceed?" : "Ќе се пренасочите кон {link}. Дали сте сигурни дека сакате да продолжите?",
+    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Ќе се пренасочите кон {host}. Дали сте сигурни дека сакате да продолжите? Врска: {link}",
     "Proceed" : "Продолжи",
     "No attachments" : "Нема прилози",
     "Add from Files" : "Додади од датотеките",
@@ -324,6 +347,7 @@ OC.L10N.register(
     "optional participant" : "незадолжителен учесник",
     "{organizer} (organizer)" : "{organizer} (organizer)",
     "{attendee} ({role})" : "{attendee} ({role})",
+    "Selected slot" : "Избран термин",
     "Availability of attendees, resources and rooms" : "Достапност на присутните, ресурси и соби",
     "Suggestion accepted" : "Сугестијата е прифатена",
     "Previous date" : "Предходен датум",
@@ -331,6 +355,7 @@ OC.L10N.register(
     "Legend" : "Легенда",
     "Out of office" : "Надвор од канцеларија",
     "Attendees:" : "Присутни:",
+    "local time" : "локално време",
     "Done" : "Готово",
     "Search room" : "Пребарај соба",
     "Room name" : "Име на соба",
@@ -350,12 +375,8 @@ OC.L10N.register(
     "Decline" : "Одбиј",
     "Tentative" : "Пробно",
     "No attendees yet" : "Сè уште нема присутни",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} поканети, {confirmedCount} потврдени",
-    "Successfully appended link to talk room to location." : "Успешно е додадена врска од собата за разговор во локација.",
-    "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
-    "Error creating Talk room" : "Грешка при креирање на соба за разговор",
+    "Please add at least one attendee to use the \"Find a time\" feature." : "Додајте барем еден учесник за да ја користите функцијата \"Пронајди време\".",
     "Attendees" : "Присутни",
-    "_%n more guest_::_%n more guests_" : ["%n гостин","%n други гости"],
     "Remove group" : "Отстрани група",
     "Remove attendee" : "Откажи присутност",
     "Request reply" : "Побарај одговор",
@@ -366,14 +387,18 @@ OC.L10N.register(
     "_%n member_::_%n members_" : ["%n член","%n членови"],
     "Search for emails, users, contacts, contact groups or teams" : "Пребарувај за е-пошти, корисници, контакти, групи или тимови",
     "No match found" : "Нема совпаѓања",
+    "Note that members of circles get invited but are not synced yet." : "Забелешка: членовите на тимовите се поканети, но сè уште не се синхронизирани.",
+    "Note that members of contact groups get invited but are not synced yet." : "Забелешка: членовите на групите за контакти се поканети, но сè уште не се синхронизирани.",
     "(organizer)" : "(organizer)",
     "Make {label} the organizer" : "Направи го {label} организатор",
+    "Make {label} the organizer and attend" : "Постави го {label} како организатор и учествувај",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
     "Remove color" : "Отстрани боја",
     "Event title" : "Наслов на настанот",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не може да се менуваат целодневните параметри за настани што се дел од множество за повторување.",
     "From" : "Од",
     "To" : "До",
+    "Your Time" : "Твоето време",
     "Repeat" : "Повтори",
     "Repeat event" : "Повтори настан",
     "_time_::_times_" : ["еднаш","пати"],
@@ -427,7 +452,10 @@ OC.L10N.register(
     "No" : "Не",
     "Maybe" : "Можеби",
     "None" : "Ништо",
+    "Select your meeting availability" : "Изберете ја вашата достапност за состанок",
+    "Create a meeting for this date and time" : "Креирај состанок за овој датум и време",
     "Create" : "Креирај",
+    "No participants or dates available" : "Нема достапни учесници или датуми.",
     "from {formattedDate}" : "од {formattedDate}",
     "to {formattedDate}" : "до {formattedDate}",
     "on {formattedDate}" : "на {formattedDate}",
@@ -445,13 +473,17 @@ OC.L10N.register(
     "Global" : "Глобално",
     "Holidays in {region}" : "Празници во {region}",
     "An error occurred, unable to read public calendars." : "Настана грешка, неможе да се прочитаат јавниоте календари.",
+    "An error occurred, unable to subscribe to calendar." : "Се појави грешка — не може да се претплати на календарот.",
     "Public holiday calendars" : "Календар со државни празници",
     "Public calendars" : "Јавни календари",
+    "No valid public calendars configured" : "Нема конфигурирани важечки јавни календари",
     "Speak to the server administrator to resolve this issue." : "Разговарајте со администраторот на серверот за да го решите овој проблем.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Календарите за државни празници се обезбедени од Thunderbird. Податоците од календарот ќе се преземат од {website}",
+    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Овие јавни календари се предложени од администраторот на серверот. Податоците од календарот ќе се преземат од соодветната веб-страница.",
     "By {authors}" : "Од {authors}",
     "Subscribed" : "Претплатени",
     "Subscribe" : "Претплата",
+    "Could not fetch slots" : "Не може да се преземат термините",
     "Select a date" : "Избери датум",
     "Select slot" : "Избери термин",
     "No slots available" : "Нема достапни термини",
@@ -469,20 +501,28 @@ OC.L10N.register(
     "Personal" : "Лично",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматското откривање на временската зона утврди дека вашата временска зона е UTC.\nОва е најверојатно резултат на безбедносните мерки на вашиот веб прелистувач\nПоставете ја вашата временска зона во подесувањата за календарот.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Вашата временска зона ({timezoneId}) не е пронајдена. Поставена е  (Координирано универзално време) UTC.\nПоставете ја вашата временска зона во подесувањата за календарот или пријавете го овој проблем.",
+    "Show unscheduled tasks" : "Прикажи незададени задачи",
+    "Unscheduled tasks" : "Нездадени задачи",
     "Availability of {displayName}" : "Достапност на {displayName}",
+    "Discard event" : "Отфрли настан",
     "Edit event" : "Уреди го настанот",
     "Event does not exist" : "Настанот не постои",
     "Duplicate" : "Дуплирај",
     "Delete this occurrence" : "Избришете ја оваа можност",
     "Delete this and all future" : "Избришете го овој и сите во иднина",
     "All day" : "Цели денови",
+    "Modifications wont get propagated to the organizer and other attendees" : "Измените нема да се применат кај организаторот и другите учесници",
     "Managing shared access" : "Управување со споделен пристап",
     "Deny access" : "Забрани пристап",
     "Invite" : "Покани",
+    "Discard changes?" : "Да се отфрлат промените?",
+    "Are you sure you want to discard the changes made to this event?" : "Дали сте сигурни дека сакате да ги отфрлите промените направени во овој настан?",
     "_User requires access to your file_::_Users require access to your file_" : ["Корисник бара пристап до вашата датотека","Корисници бараат пристап до вашата датотека"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прилог за кој е потребен пристап","Прилози за кои е потребен пристап"],
     "Untitled event" : "Неименуван настан",
     "Close" : "Затвори",
+    "Modifications will not get propagated to the organizer and other attendees" : "Измените нема да бидат применети кај организаторот и другите учесници",
+    "Meeting proposals overview" : "Преглед на предлози за состаноци",
     "Edit meeting proposal" : "Измени предлог за состанок",
     "Create meeting proposal" : "Креирај предлог за состанок",
     "Update meeting proposal" : "Ажурирај предлог за состанок",
@@ -494,6 +534,8 @@ OC.L10N.register(
     "Successfully created meeting for {date}" : "Успешно креиран состанок за {date}",
     "Failed to create a meeting for {date}" : "Неуспешно креиран состанок за {date}",
     "Please enter a valid duration in minutes." : "Внесете валидно времетраење во минути.",
+    "Failed to fetch proposals" : "Не успеа да се преземат предлозите",
+    "Failed to fetch free/busy data" : "Не успеа да се преземат податоците за достапност",
     "Selected" : "Избрани",
     "No Description" : "Нема опис",
     "No Location" : "Нема локација",
@@ -506,7 +548,14 @@ OC.L10N.register(
     "90 min" : "90 мин",
     "Participants" : "Учесници",
     "Selected times" : "Избрани времиња",
+    "Previous span" : "Претходен период",
+    "Next span" : "Следен период",
+    "Less days" : "Помалку денови",
     "More days" : "Повеќе денови",
+    "Loading meeting proposal" : "Се вчитува предлог за состанок",
+    "No meeting proposal found" : "Не е пронајден предлог за состанок",
+    "Please wait while we load the meeting proposal." : "Почекајте додека се вчита предлогот за состанок.",
+    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Врската што ја следевте можеби е невалидна, или предлогот за состанок повеќе не постои.",
     "Thank you for your response!" : "Благодариме на вашиот одговор.",
     "Your vote has been recorded. Thank you for participating!" : "Вашиот глас е регистриран. Благодариме за учеството!",
     "Unknown User" : "Непознат корисник",
@@ -567,12 +616,14 @@ OC.L10N.register(
     "last" : "последен",
     "Untitled task" : "Неименувана задача",
     "Please ask your administrator to enable the Tasks App." : "Замолете го сервер администраторот да ја овозможи апликацијата задачи.",
+    "You are not allowed to edit this event as an attendee." : "Немате дозвола да го уредувате овој настан како учесник.",
     "W" : "Н",
     "%n more" : "%n други",
     "No events to display" : "Нема настани за приказ",
     "All participants declined" : "Сите учесници одбија",
     "Please confirm your participation" : "Ве молиме потврдете го вашато присуство",
     "You declined this event" : "Вие го одбивте овој настан",
+    "Your participation is tentative" : "Вашето учество е привремено",
     "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
     "No events" : "Нема настани",
     "Create a new event or change the visible time-range" : "Креирајте нов настан или променете го видливиот временски опсег",
@@ -587,7 +638,7 @@ OC.L10N.register(
     "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
     "When shared show only busy" : "Кога е споделен, прикажи зафатено",
     "When shared hide this event" : "Кога е споделен, сокриј го настанот",
-    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
+    "The visibility of this event in read-only shared calendars." : "Видливоста на овој настан во споделени календари со само-преглед.",
     "Add a location" : "Додади локација",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Додај опис\n\n- За што е овој состанок\n- Точки на дневен ред\n- Сè што учесниците треба да подготват",
     "Status" : "Статус",
@@ -604,22 +655,49 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Специјална боја на овој настан. Ја отфрла бојата на календарот.",
     "Error while sharing file" : "Грешка при споделување на датотека",
     "Error while sharing file with user" : "Грешка при споделување на датотека со корисник",
+    "Error creating a folder {folder}" : "Грешка при создавање на папката {folder}",
     "Attachment {fileName} already exists!" : "Прилогот {fileName} веќе постои!",
     "Attachment {fileName} added!" : "Прилогот {fileName} е додаден!",
     "An error occurred during uploading file {fileName}" : "Настана грешка при прикачување на датотека {fileName}",
     "An error occurred during getting file information" : "Настана грешка при преземање на информации од датотека",
+    "Talk conversation for proposal" : "Talk разговор за предлогот",
     "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
     "Imported {filename}" : "Импортирано {filename}",
     "This is an event reminder." : "Ова е потсетник за настан.",
+    "Error while parsing a PROPFIND error" : "Грешка при обработка на PROPFIND грешката",
     "Appointment not found" : "Терминот не е пронајден",
     "User not found" : "Корисникот не е пронајден",
     "Hidden" : "Сокриен",
+    "can edit" : "може да се измени",
     "Calendar name …" : "Име на календар ...",
+    "Default attachments location" : "Стандардна локација за прилози",
     "Automatic ({detected})" : "Автоматски ({detected})",
     "Shortcut overview" : "Преглед на кратенки преку тастатура",
+    "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
+    "Enable birthday calendar" : "Овозможи календар со родендени",
+    "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
     "Enable simplified editor" : "Овозможи поедноставен уредувач",
     "Limit the number of events displayed in the monthly view" : "Ограничи број на настани прикажани во месечниот преглед",
+    "Show weekends" : "Прикажи викенди",
+    "Show week numbers" : "Прикажи броеви на неделите",
     "Time increments" : "Временско зголемување",
-    "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура"
+    "Default calendar for incoming invitations" : "Стандарден календар за дојдовни покани",
+    "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
+    "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
+    "Personal availability settings" : "Параметри за лична достапност",
+    "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура",
+    "Create a new public conversation" : "Создај нов јавен разговор",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} поканети, {confirmedCount} потврдени",
+    "Successfully appended link to talk room to location." : "Успешно е додадена врска од собата за разговор во локација.",
+    "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
+    "Error creating Talk room" : "Грешка при креирање на соба за разговор",
+    "_%n more guest_::_%n more guests_" : ["%n гостин","%n други гости"],
+    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
+    "View options" : "Прегледај опции ",
+    "Limit number of events shown in month view" : "Ограничи го бројот на прикажани настани во месечен преглед",
+    "Time division in day and week view" : "Поделба на време во дневен и неделен преглед",
+    "Enable simple editor" : "Овозможи едноставен уредувач",
+    "Keyboard shortcuts" : "Кратенки преку тастатура"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
