@@ -111,11 +111,9 @@ OC.L10N.register(
     "Could not copy code" : "Não foi possível copiar o código",
     "Delete share link" : "Apagar hiperligação de partilha",
     "Deleting share link …" : "A apagar hiperligação de partilha",
-    "can edit" : "pode editar",
     "Unshare with {displayName}" : "Cancelar partilha com {displayName}",
     "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
     "No users or groups" : "Sem utilizadores ou grupos",
-    "Calendar name …" : "Nome do calendário…",
     "Share calendar" : "Partilhar calendário",
     "Unshare from me" : "Cancelar partilha",
     "Save" : "Guardar",
@@ -151,19 +149,10 @@ OC.L10N.register(
     "or" : "ou",
     "Calendar settings" : "Configurações do calendário",
     "No reminder" : "Nenhum lembrete",
-    "CalDAV link copied to clipboard." : "Ligação CalDAV copiada para a área de transferência.",
-    "CalDAV link could not be copied to clipboard." : "Não foi possível copiar a ligação CalDAV para a área de transferência.",
     "General" : "Geral",
-    "Personal availability settings" : "Configurações de disponibilidade pessoal",
-    "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
-    "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
-    "Enable birthday calendar" : "Ativar calendário de aniversários",
-    "Show tasks in calendar" : "Mostrar tarefas no calendário",
-    "Show weekends" : "Mostrar fins-de-semana",
-    "Show week numbers" : "Mostrar o número das semanas",
     "Editing" : "A editar",
     "Default reminder" : "Lembrete padrão",
-    "Keyboard shortcuts" : "Atalhos de teclado",
+    "Files" : "Ficheiros",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
@@ -307,10 +296,22 @@ OC.L10N.register(
     "An error occurred, unable to delete the calendar." : "Ocorreu um erro que impede que o calendário seja apagado",
     "User not found" : "Utilizador não encontrado",
     "Hidden" : "Escondido",
+    "can edit" : "pode editar",
+    "Calendar name …" : "Nome do calendário…",
     "Automatic ({detected})" : "Automático ({detected})",
     "Shortcut overview" : "Visão geral de atalhos",
+    "CalDAV link copied to clipboard." : "Ligação CalDAV copiada para a área de transferência.",
+    "CalDAV link could not be copied to clipboard." : "Não foi possível copiar a ligação CalDAV para a área de transferência.",
+    "Enable birthday calendar" : "Ativar calendário de aniversários",
+    "Show tasks in calendar" : "Mostrar tarefas no calendário",
     "Enable simplified editor" : "Ativar editor simplificado",
+    "Show weekends" : "Mostrar fins-de-semana",
+    "Show week numbers" : "Mostrar o número das semanas",
     "Time increments" : "Incrementos de tempo",
-    "Show keyboard shortcuts" : "Mostrar atalhos de teclado"
+    "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
+    "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
+    "Personal availability settings" : "Configurações de disponibilidade pessoal",
+    "Show keyboard shortcuts" : "Mostrar atalhos de teclado",
+    "Keyboard shortcuts" : "Atalhos de teclado"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
