@@ -129,7 +129,6 @@ OC.L10N.register(
     "Deleting share link …" : "Se şterge linkul de partajare ...",
     "An error occurred while unsharing the calendar." : "Eroare la eliminarea partajării calendarului.",
     "An error occurred, unable to change the permission of the share." : "A apărut o eroare, nu se poate schimba permisiunile fişierelor partajate.",
-    "can edit" : "poate edita",
     "Unshare with {displayName}" : "Retrage cu {displayName}",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
@@ -148,7 +147,7 @@ OC.L10N.register(
     "Invalid location selected" : "Locație invalidă",
     "Attachments folder successfully saved." : "Folderul de atașamente a fost salvat.",
     "Error on saving attachments folder." : "Eroare la salvarea folderului de atașamente.",
-    "Default attachments location" : "Locația implicită a atașamentelor",
+    "Attachments folder" : "Dosarul pentru atașamente",
     "{filename} could not be parsed" : "{filename} nu a putut fi analizat",
     "No valid files found, aborting import" : "Nu au fost găsite fişiere valide, importarea se opreşte",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["A fost importat %n eveniment","Au fost importate %n evenimente","Au fost importate %n evenimente"],
@@ -175,19 +174,10 @@ OC.L10N.register(
     "or" : "sau",
     "Calendar settings" : "Setări calendar",
     "No reminder" : "Fără mementouri",
-    "CalDAV link copied to clipboard." : "Link-ul CAlDAV a fost copiat în clipboard.",
-    "CalDAV link could not be copied to clipboard." : "Linkul CalDAV nu a putut fi copiat în clipboard.",
     "General" : "General",
-    "Personal availability settings" : "Setări de disponibilitate",
-    "Copy primary CalDAV address" : "Copiază adresa primară CalDAV",
-    "Copy iOS/macOS CalDAV address" : "Copiază adresa iOS/OS X CalDAV",
-    "Enable birthday calendar" : "Activează calendarul cu zile de naştere",
-    "Show tasks in calendar" : "Arată sarcinile în calendar",
-    "Show weekends" : "Arată weekend-uri",
-    "Show week numbers" : "Afișați numerele săptămânilor",
+    "Appearance" : "Aspect",
     "Editing" : "Se modifică",
     "Default reminder" : "Memento implicit",
-    "Keyboard shortcuts" : "Scurtături din tastatură",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minute","{duration} de minute"],
     "0 minutes" : "0 minute",
     "_{duration} hour_::_{duration} hours_" : ["{duration} oră","{duration} ore","{duration} de ore"],
@@ -290,9 +280,6 @@ OC.L10N.register(
     "Decline" : "Refuză",
     "Tentative" : "Tentativă",
     "No attendees yet" : "Nu exista participați încă",
-    "Successfully appended link to talk room to location." : "S-a adăugat cu succes locației linkul la camera Talk.",
-    "Successfully appended link to talk room to description." : "S-a adăugat cu succes descrierii linkul la camera Talk.",
-    "Error creating Talk room" : "Camera Talk nu a putut fi creată",
     "Attendees" : "Participanți",
     "Remove group" : "Înlătură grupul",
     "Remove attendee" : "Elimină participant",
@@ -474,7 +461,6 @@ OC.L10N.register(
     "When shared show full event" : "Arată tot evenimentul la partajare",
     "When shared show only busy" : "Arată doar ocupat la partajare",
     "When shared hide this event" : "Ascunde evenimentul la partajare",
-    "The visibility of this event in shared calendars." : "Vizibilitatea acestui eveniment în calendarele partajate.",
     "Add a location" : "Adaugă o locație",
     "Status" : "Stare",
     "Confirmed" : "Confirmat",
@@ -498,12 +484,28 @@ OC.L10N.register(
     "Appointment not found" : "Programarea nu a fost găsită",
     "User not found" : "Utilizatorul nu a fost găsit",
     "Hidden" : "Ascuns",
+    "can edit" : "poate edita",
     "Calendar name …" : "Numele calendarului ...",
+    "Default attachments location" : "Locația implicită a atașamentelor",
     "Automatic ({detected})" : "Automat ({detectat})",
     "Shortcut overview" : "Prezentare generală a comenzilor rapide",
+    "CalDAV link copied to clipboard." : "Link-ul CAlDAV a fost copiat în clipboard.",
+    "CalDAV link could not be copied to clipboard." : "Linkul CalDAV nu a putut fi copiat în clipboard.",
+    "Enable birthday calendar" : "Activează calendarul cu zile de naştere",
+    "Show tasks in calendar" : "Arată sarcinile în calendar",
     "Enable simplified editor" : "Activează editorul simplificat",
     "Limit the number of events displayed in the monthly view" : "Limitează numărul evenimentelor în vizualizare lunară",
+    "Show weekends" : "Arată weekend-uri",
+    "Show week numbers" : "Afișați numerele săptămânilor",
     "Time increments" : "Incremente de timp",
-    "Show keyboard shortcuts" : "Arată scurtături"
+    "Copy primary CalDAV address" : "Copiază adresa primară CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Copiază adresa iOS/OS X CalDAV",
+    "Personal availability settings" : "Setări de disponibilitate",
+    "Show keyboard shortcuts" : "Arată scurtături",
+    "Successfully appended link to talk room to location." : "S-a adăugat cu succes locației linkul la camera Talk.",
+    "Successfully appended link to talk room to description." : "S-a adăugat cu succes descrierii linkul la camera Talk.",
+    "Error creating Talk room" : "Camera Talk nu a putut fi creată",
+    "The visibility of this event in shared calendars." : "Vizibilitatea acestui eveniment în calendarele partajate.",
+    "Keyboard shortcuts" : "Scurtături din tastatură"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
