@@ -160,6 +160,7 @@ OC.L10N.register(
     "Automatic" : "ئاپتوماتىك",
     "Automatic ({timezone})" : "ئاپتوماتىك ({timezone})",
     "New setting was not saved successfully." : "يېڭى تەڭشەك مۇۋەپپەقىيەتلىك ساقلانمىدى.",
+    "Timezone" : "ۋاقىت رايۇنى",
     "Navigation" : "يول باشلاش",
     "Previous period" : "ئالدىنقى مەزگىل",
     "Next period" : "كېيىنكى مەزگىل",
@@ -182,18 +183,18 @@ OC.L10N.register(
     "At event start" : "پائالىيەت باشلانغاندا",
     "No reminder" : "ئەسكەرتىش يوق",
     "Failed to save default calendar" : "سۈكۈتتىكى كالېندارنى ساقلىيالمىدى",
-    "CalDAV link copied to clipboard." : "CalDAV ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
     "General" : "General",
-    "Copy iOS/macOS CalDAV address" : "IOS / macOS CalDAV ئادرېسىنى كۆچۈرۈڭ",
     "Appearance" : "كۆرۈنۈش",
     "Editing" : "تەھرىرلەش",
-    "Default calendar for incoming invitations" : "كەلگەن تەكلىپلەرنىڭ سۈكۈتتىكى كالېندارى",
     "Default reminder" : "كۆڭۈلدىكى ئەسكەرتىش",
-    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
     "Appointment schedule successfully created" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك قۇرۇلدى",
     "Appointment schedule successfully updated" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك يېڭىلاندى",
+    "_{duration} minute_::_{duration} minutes_" : ["{duration} مىنۇت","{duration} مىنۇت"],
     "0 minutes" : "0 مىنۇت",
+    "_{duration} hour_::_{duration} hours_" : ["{duration} سائەت","{duration} سائەت"],
+    "_{duration} day_::_{duration} days_" : ["{duration} كۈن","{duration} كۈن"],
+    "_{duration} month_::_{duration} months_" : ["{duration} ئاي","{duration} ئاي"],
+    "_{duration} year_::_{duration} years_" : ["{duration} يىل","{duration} يىل"],
     "To configure appointments, add your email address in personal settings." : "ئۇچرىشىشنى تەڭشەش ئۈچۈن ئېلېكترونلۇق خەت ئادرېسىڭىزنى شەخسىي تەڭشەكلەرگە قوشۇڭ.",
     "Public – shown on the profile page" : "ئاممىۋى - ئارخىپ بېتىدە كۆرسىتىلدى",
     "Private – only accessible via secret link" : "شەخسىي - پەقەت مەخپىي ئۇلىنىش ئارقىلىقلا زىيارەت قىلغىلى بولىدۇ",
@@ -309,9 +310,6 @@ OC.L10N.register(
     "Decline" : "رەت قىلىش",
     "Tentative" : "Tentative",
     "No attendees yet" : "ھازىرغىچە قاتناشقۇچىلار يوق",
-    "Successfully appended link to talk room to location." : "مۇۋەپپەقىيەتلىك ھالدا پاراڭلىشىش ئۆيىگە ئۇلىنىش قوشۇلدى.",
-    "Successfully appended link to talk room to description." : "مۇۋەپپەقىيەتلىك ھالدا سۆزلىشىش ئۆيىگە ئۇلىنىش قوشۇلدى.",
-    "Error creating Talk room" : "سۆھبەت ئۆيى قۇرۇشتا خاتالىق",
     "Attendees" : "قاتناشقۇچىلار",
     "Remove group" : "گۇرۇپپىنى ئۆچۈرۈڭ",
     "Remove attendee" : "قاتناشقۇچىلارنى ئېلىۋېتىڭ",
@@ -520,6 +518,8 @@ OC.L10N.register(
     "Default attachments location" : "كۆڭۈلدىكى قوشۇمچە ئورنى",
     "Automatic ({detected})" : "ئاپتوماتىك ({detected})",
     "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
+    "CalDAV link copied to clipboard." : "CalDAV ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
     "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
     "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
     "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
@@ -527,10 +527,16 @@ OC.L10N.register(
     "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
     "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
     "Time increments" : "ۋاقىت كۆپەيدى",
+    "Default calendar for incoming invitations" : "كەلگەن تەكلىپلەرنىڭ سۈكۈتتىكى كالېندارى",
     "Copy primary CalDAV address" : "دەسلەپكى CalDAV ئادرېسىنى كۆچۈرۈڭ",
+    "Copy iOS/macOS CalDAV address" : "IOS / macOS CalDAV ئادرېسىنى كۆچۈرۈڭ",
     "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
     "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت",
     "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} قىلىنغان سان} تەكلىپ قىلىنغان ، {confirmedCount} سان} جەزملەشتۈرۈلگەن",
-    "The visibility of this event in shared calendars." : "ئورتاق كالېنداردا بۇ پائالىيەتنىڭ كۆرۈنۈشچانلىقى."
+    "Successfully appended link to talk room to location." : "مۇۋەپپەقىيەتلىك ھالدا پاراڭلىشىش ئۆيىگە ئۇلىنىش قوشۇلدى.",
+    "Successfully appended link to talk room to description." : "مۇۋەپپەقىيەتلىك ھالدا سۆزلىشىش ئۆيىگە ئۇلىنىش قوشۇلدى.",
+    "Error creating Talk room" : "سۆھبەت ئۆيى قۇرۇشتا خاتالىق",
+    "The visibility of this event in shared calendars." : "ئورتاق كالېنداردا بۇ پائالىيەتنىڭ كۆرۈنۈشچانلىقى.",
+    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى"
 },
 "nplurals=2; plural=(n != 1);");
