@@ -151,14 +151,11 @@ OC.L10N.register(
     "Delete edited event" : "Xoá sự kiện được chỉnh sửa",
     "or" : "hoặc",
     "No reminder" : "Không có nhắc hẹn",
-    "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
-    "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
     "General" : "Cài đặt chung",
-    "Copy iOS/macOS CalDAV address" : "Sao chép địa chỉ CalDAV cho iOS/macOC",
     "Appearance" : "Giao diện",
     "Editing" : "Chỉnh sửa",
     "Default reminder" : "Nhác hẹn mặc định",
-    "Keyboard shortcuts" : "Phím tắt",
+    "Files" : "Tệp Tin",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} phút"],
     "0 minutes" : "0 phút",
     "_{duration} hour_::_{duration} hours_" : ["{duration} giờ"],
@@ -246,8 +243,6 @@ OC.L10N.register(
     "Decline" : "Từ chối",
     "Tentative" : "Chưa chắc chắn",
     "No attendees yet" : "Chưa có giờ tham gia",
-    "Successfully appended link to talk room to description." : "Liên kết đã được thêm thành công vào mô tả trong phòng trò chuyện ",
-    "Error creating Talk room" : "Có lõi xảy ra khi tạo phòng Trò chuyện",
     "Attendees" : "Người tham gia",
     "Remove group" : "Xóa nhóm",
     "Remove attendee" : "Gỡ bỏ người tham gia",
@@ -440,6 +435,8 @@ OC.L10N.register(
     "can edit" : "có thể chỉnh sửa",
     "Automatic ({detected})" : " ({detected}) tự động",
     "Shortcut overview" : "Bản xem trước của lối tắt",
+    "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
+    "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
     "Enable birthday calendar" : "Bật lịch sinh nhật",
     "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
     "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
@@ -447,8 +444,12 @@ OC.L10N.register(
     "Show week numbers" : "Hiển thị số tuần",
     "Time increments" : "Mức tăng thời gian",
     "Copy primary CalDAV address" : "Sao chép địa chỉ CalDAV chính",
+    "Copy iOS/macOS CalDAV address" : "Sao chép địa chỉ CalDAV cho iOS/macOC",
     "Personal availability settings" : "Thiết lập lịch trống cá nhân",
     "Show keyboard shortcuts" : "Hiển thị các phím tắt",
-    "The visibility of this event in shared calendars." : "Khả năng nhìn thấy của sự kiện này trong các lịch được chia sẻ"
+    "Successfully appended link to talk room to description." : "Liên kết đã được thêm thành công vào mô tả trong phòng trò chuyện ",
+    "Error creating Talk room" : "Có lõi xảy ra khi tạo phòng Trò chuyện",
+    "The visibility of this event in shared calendars." : "Khả năng nhìn thấy của sự kiện này trong các lịch được chia sẻ",
+    "Keyboard shortcuts" : "Phím tắt"
 },
 "nplurals=1; plural=0;");
